% MATLAB_SCRIPTS_DEVELOPMENT
%
% General
%   installation - this script installs the wavelet toolbox toolset
%
% PHYSICAL_SPACE
%
% Statistical tools
%
%   cmom                - Calculates the pth order central moment of the signal f
%   cmratio             - Calculates the ratio of the centered moments of a distribution
%   flat                - Calculates the flatness of the signal f
%   kurt                - Calculates the kurtosis of the input signal
%   mom                 - Calculates the pth order moment of the input signal
%   mratio              - Calculates the ratio of moments of a distribution
%   nent                - calculate the 'entropy', E, of the input signal, X
%   nmpdf               - Calcuate a normalized PDF using the hist function
%   pdf_centered        - Calculates the centered PDF of the input signal
%   rms                 - Calculates the root mean square (RMS) of the input signal
%   signalstats         - Calculates the statistics of the input signal
%   skew                - Calculates the skewness of the input signal
%
% FOURIER_SPACE
%
%   conv_f               - Convolution of two 1D signals
%   corr_f               - Correlation of two 1D signals
%   cross_spectrum       - Calculate the cross spectrum of two signals
%   energyspectrum2D     - Calculates the 1D Energy spectrum function of input vector field
%   periodogram          - Computes the periodogram (energy spectrum?)
%   spectre              - Simple periodogram (obsolete)
%   spectrum1D           - Computes the periodogram (1D spectrum) of a 1D signal
%   spectrum2D           - Calculates the 2D spectrum of the input 2D field
%
% Fourier-space filtering
%
%   bwfilter2d           - Butterworth filter in 2D
%   filt_lin_f           - Linear Fourier filtering of a signal
%   filt_nonlin_f        - Nonlinear Fourier filtering of a signal
%   fft2downsample       - Downsample a signal by truncating in Fourier space
%   fft2upsample         - Up sample a function by FFT (2D)
%   fft2zeropad          - 2D zeropad in Fourier space
%   fftdownsample        - Downsample a 1D signal by truncating in Fourier space
%   fftupsample          - Up sample a 1D signal by FFT
%   fftzeropad           - 1D zeropad in Fourier space
%
% Fourier-space utilities
%
%   flipks               - Perform the operation k -> -k
%   fmodes               - Returns the corresponding 1D Fourier modes for a vector of size N
%   fmodes2              - Returns the 2D Fourier modes for a vector of size N
%
% Other Fourier-space calculations
%
%   fourier_vort         - Calculate vorticity from velocity using the FFT
%   vort2stream          - Calculate the stream function from the vorticity (using FFT2)
%
%
% Generate signals
%
%   burgers              - Create a burgers vortex field
%   gen_dirac            - Generate a dirac
%   gen_sinusoid         - Generate a sinusoid
%   gen_step             - Generate a step function
%   gen_wnoise           - Generate Gaussian white noise (using randn)
%   gaussianfield2D      - Generate an N x N divergence free vector field with Gaussian statistics
%   gaussianfield2Dspec  - Generate an N x N divergence free
%   wind                 - Generate a window function (specified)
%   wind2                - Generate a 2D window function (specified)
%
% Other miscellaneous tools
%
%   clip                - Clipping / Thresholding function
%   structure_function  - Calculates the structure function, order p of the input signal
%
% WAVELETS
%
% Generate Wavelets
%
%   gen_cmorlet          - Generation of a Complex Morlet wavelet
%   gen_cmorlet2D        - Generation of a 2D Complex Morlet wavelet
%   gen_mexh             - Generate a real-valued Mexican Hat wavelet
%
% Continuous Wavelet Transform (1D)
%
%   ICWT_P              - Continuous inverse wavelet transform reconstruction
%   ICWT_mexh           - ICWT using the mexican hat wavelet
%   cwscale             - Conversion between various types of scales of the continuous wavelet
%   cwscales            - Returns the scales given the number of octaves and voices per octave
%   cwt1d               - 1D CWT
%   intfactor1D         - 1D Intermittency factor calculated from the 1D CWT coefficients
%   wphase              - Calculate the phase of the CWT coefficients
%   waveletspectrum1D   - Calculate the 1D wavelet spectrum of a signal
%   doCWTanalysis       - Perform a full CWT analysis of the input signal
%
% Continuous Wavelet Transform (2D)
%
%   cwt2D               - 2D CWT with complex Morlet wavelet
%   intfactor2D         - 2D Intermittency factor calculated from 2D CWT coefficients
%   localRe2D           - 2D Local Reynolds number calculated from 2D CWT coefficients of velocity
%   waveletspectrum2D   - Calculate the 2D wavelet spectrum of a signal
%
%
% Orthogonal Wavelet Tools
%
%	Denoising (OWT)
%
%   extract1D          - Denoising of a signal by the orthogonal wavelet
%   extract2D          - Denoising of 2D signal by the orthogonal wavelet transform
%   extract2D_jori     - Denoising by OWT using an entropy criterion
%   extract2D_noiter   - Non-Iterative version of Marie's coherent structure extraction algorithm
%
%	Other OWT
%
%   compressioncurve      - Calculates the compression curve for the orthogonal wavelet transform of a signal
%   corr_w                - Correlation of two 1D signals in wavelet space
%   dwt1D_level_energy    - Return the energy contained in the coefficients 
%   dwt2D_level_energy    - Return the energy contained in the coefficients 
%   dwt_levels2D          - Separate the coefficients of the 2D DWT by level
%   dwt_levels_const2D    - Reconstruct the coefficient matrix of the 2D DWT by level
%   doOWTanalysis         - Perform a full OWT analysis of the input signal   
%   filt_lin_w            - "Quasi-linear" Wavelet filtering of a signal
%   OWTwaveletspectrum1D  - Calculate the 1D wavelet spectrum of a signal from the OWT coefficients
%   OWTwaveletspectrum2D  - Calculate the 2D wavelet spectrum of a signal from the OWT coefficients
%   OWTwaveletspectrum1D  - Calculate the 1D wavelet scalogram of a signal from the OWT coefficients
%
% Plotting
%
%   drawfield          - Draw a 2D scalar field using the Marie's palette and upsampling
%   drawCWT1D          - Draw the coefficients of the 1D CWT
%   drawCWT2D          - Draw the coefficients of the 2D CWT (needs improvement)
%   drawDWT1D          - Draw the coefficients of the 1D OWT
%   drawLIF1D          - Draw the 1D local intermittency factor
%   PaletteMarie       - PaletteMarie(Type,taille,limite_faible_fort,etalement_du_zero)
%   PaletteMarie2      - Generates a new colormap for use with displaying scalar fields
%   plotlimits         - Returns reasonable min and max y plotting limits for a given input signal