function C = corr_f(f,g)
% Correlation of two 1D signals
%
% Usage:
%   C = corr_f(f,g);
%
% Correlation of two 1D signals f and g
% uses Fourier transform to perform the correlation.
% f and g should be periodic signals of length 2^N 
%
% Inputs:
%   f - 1D signal
%   g - 1D signal
% Outputs:
%   C - correlation of the two signals
%
% Example:
%   N = 512;
%   sig1 = randn(1,N);
%   sig2 = [sig1(101:end),sig1(1:100)];
%   C = corr_f(sig1,sig2);
%   lagt = fftshift(fmodes(N));
%   plot(lagt,fftshift(C));xlabel('Lag');ylabel('Correlation);
%
% See also CONV_F

% TODO: accept as input physical grid
% Updates: 4/10/2007 Subtract mean from signals; correlation at large separation goes to zero

if ~exist('g','var');
    g = f; % perform autocorrelation
end %if
f = f - mean(f);g = g - mean(g); % Subtract mean: added 4/10/2007

% the Fourier transforms of the two signals
Ff = fft(f);Fg = fft(g);

% multiply Fourier transforms and take the inverse
C = ifft(Ff.*conj(Fg));

% Normalize the correlation
C = C./sqrt(sum(f.^2)*sum(g.^2));

% Matlab dependencies: fft, ifft, conj
% Created 2/6/2006 Jori