function [Co,Qs,fk] = cross_spectrum(f1,f2,delta)
% Calculate the cross spectrum of two signals
%
% Usage:
%   [Co,Qs,fk] = cross_spectrum(f1,f2);
%
% Calculate the cross spectrum of the two signals.
% The cross spectrum is the Fourier transform of the convolution of the
% signals
%
% Inputs:
%   f1 - 1D signal
%   f2 - 1D signal
%   delta - time between samples (optional)
%
% Outputs:
%   Co - cospectrum (real part of cross spectrum)
%   Qs - quadrature spectrum (imaginary part of cross spectrum)
%   fk - frequencies (wavenumbers)
%
% TODO: Clean this code

N = length(f1); % assume that f1 and f2 have the same lengths

% use the convolution theorem

% Fourier transforms of the signals
Ff1 = fft(f1);Ff2 = fft(f2);

% the cross spectrum
modCs = (1/N^2)*conj(Ff1).*Ff2;

k = [2:N/2]; % frequencies // used as indices
Cs(k) = modCs(k) + modCs( (N+2) - k); % energy
Cs(1) = modCs(1); % zero-frequency mode (energy in mean value)
Cs(N/2+1) = modCs(N/2+1);

Co = real(Cs); % Cospectrum: the real part of the cross spectrum
Qs = imag(Cs); % Quadrature spectrum: the imaginary part of the cross spectrum

k = [0:N/2]; % frequencies: mode numbers

% frequencies, based upon sampling interval, etc

% delta = sampling frequency of signal
% if delta not input, default to 1
if ~exist('delta','var');delta = 1;end %if
fk = k;
fk = k/N/delta; % real frequencies


% Matlab dependencies: length, fft, real, imag, conj, exist
% Created: 2/9/2006 Jori