function usig = fft2upsample(sig,n)
% Up sample a function by FFT (2D)
%
% Usage:
%   usig = fft2upsample(sig,n);
%
% Up sample a function by FFT (2D)
% (zero pad in Fourier space and inverse transform)
%
% Inputs:
%   sig - signal to be resampled
%   n - resampling size of signal: n x n
% Outputs:
%   usig - upsampled signal
%
% See also: fftupsample, fftdownsample, fft2downsample, fftzeropad, fft2zeropad

[M,N] = size(sig); % original signal size [rows,columns]

Fsig = fft2(sig); % Fourier transform of signal

[zpdFsig] = fft2zeropad(Fsig,n); % zeropad in Fourier space

zpdFsig = zpdFsig*(n/N)*(n/M); % renormalize to preserve mean

usig = ifft2(zpdFsig,'symmetric'); % up sampled signal


% Created 8/23/2006 Jori