function [zpdFy] = fft2zeropad(Fy,N)
% 2D zeropad in Fourier space
%
% Usage:
%   [zpdFy] = fft2zeropad(Fy,N);
% 2D zeropad in Fourier space
%
% Inputs:
%   Fy - FFT of signal
%   N - new size of signal
% Outputs:
%   zpdFy - zeropadded FFT of Fy
%
% See also FFT1ZEROPAD

[m,n] = size(Fy);


nzsr = N - m; % number of zero rows to add
nzsc = N - n; % number of zero columns to add

% quadrants of the FFT, starting in the upper left
q1 = Fy(1:m/2,1:n/2);
q2 = Fy(1:m/2,n/2+1:n);
q3 = Fy(m/2+1:m,n/2+1:n);
q4 = Fy(m/2+1:m,1:n/2);

zpdr = zeros(nzsr,n/2); % zeropad rows to add
zpdc = zeros(nzsr+m,nzsc); % zeropad columns to add

zpdFy = [ [q1;zpdr;q4] , zpdc , [q2;zpdr;q3] ];

% Created 5/17/2006 Jori