function [zpdFy,k] = fftzeropad(Fy,N)
% 1D zeropad in Fourier space
%
% Usage:
%   [zpdFy,k] = fftzeropad(Fy,N);
% 1D zeropad in Fourier space
%
% Inputs:
%   Fy - FFT of signal
%   N - new size of signal
% Outputs:
%   zpdFy - zeropadded FFT of Fy
%   k - new frequencies
%
% See also FFT2ZEROPAD

nFy = size(Fy,1);

nzs = N - nFy; % number of zeros to add

if(nzs >= 0)
zerosize = size(Fy);
zerosize(1) = nzs;
zpd = zeros(zerosize); % zeros to add

%zpdFy = [Fy(1:nFy/2) zpd Fy(nFy/2+1:end)];
zpdFy = cat(1, Fy(1:nFy/2, :), zpd, Fy(nFy/2+1:end, :));

% new Frequencies

        % Frequencies (mode numbers) in wrap-around order
        k = [1:N/2-1];
        k = [0 k -N/2 -fliplr(k)];
        delta = 1/N; % use dx from finer grid??
        fk = k/N/delta; % real frequencies
        k = fk;
else
    if(mod(N,2))
        error('odd length not supported');
    end
    k = fmodes(N);
    zpdFy = Fy([1:N/2 end-N/2+1:end] ,:);
    
end

% Created 5/17/2006 Jori
% Modified 4/03/2010 Romain