function [kx,ky] = fmodes2(N,L)
% Returns the 2D Fourier modes for a vector of size N
% in the same order as the coefficients returned by fft2 
% If the physical length Lx or Ly is not specified, then a length
% L = 1 is assumed.
%
% Usage:
%   [kx,ky] = fmodes2(N,L);
%
%
% Input:
%   N - size of vector, can be 2 element [Nr, Nc], i.e. number of rows-columns
%       (this is generally the output of the size() function)
%   L - physical length of data set, or [Lx, Ly] (optional)
% Output:
%   kx - x-direction Fourier modes in same order returned by FFT
%   ky - y-direction Fourier modes in same order returned by FFT
%
% See also fmodes

% TODO: improve help

if nargin<2
    L = [1 1];
end %if
    if length(L)==1
        L = [L(1) L(1)];
    end %if
    if length(N)==1
        N = [N(1) N(1)];
    end %if
    
    Lx=L(1);Ly=L(2);
    Nx=N(2);Ny=N(1);

            tkx =fmodes(Nx,Lx);
            tky =fmodes(Ny,Ly);

            
            [kx,ky] = meshgrid(tkx,tky); % grid of frequencies

% Created 6/20/2006 Jori