function [E,k] = spectrum1D(f,x)
% Computes the periodogram (1D spectrum) of a 1D signal
%
% Usage:
%   [E,k] = spectrum1D(f,x);
%
% This function computes the periodogram (1D spectrum)
% of the signal f
% Assumes uniform sampling of the signal
% *uses no windowing and no smoothing
%
% Inputs:
%   f - signal
%   x - delta_x or sample grid (optional)
%
% Outputs:
%   E - periodogram
%   k - wavenumbers 
%
% See also: spectrum2D, energyspectrum2D

% TODO improve function, help, etc

N = length(f); % number of elements in the signal

Ff = fft(f); % the Fourier transform of the signal

modFf = ( Ff.*conj(Ff) ) /N/N; % normalized modulus of coefficients
% modified 2/13/2007 Jori, changed (1/N^2) * to /N/N, the (1/N^2) could
% yield complex result, reason unknown!

k = [2:N/2-1]; % frequencies // used as indices
E(k) = modFf(k) + modFf( (N+2) - k); % energy
E(1) = modFf(1); % zero-frequency mode (energy in mean value)
%E(floor(N/2) +1) = modFf( floor(N/2) +1);
E(N/2) = modFf( N/2); % highest wavenumber

k = [0:N/2-1]; % frequencies: mode numbers

% return frequencies, based upon sampling interval, etc
% get Delta for conversion to real frequencies
if nargin < 2; 
    Delta = 1; 
else
    if isscalar(x);
        Delta = x;
    else
        Delta = x(2)-x(1);
    end %if else
        fk = k/N/Delta; % real frequencies, in Hz, no pi necessary
        k = fk;
end; %if else


% matlab dependencies: length, fft, conj
% Created: 2/8/2006 Jori