function [k,e] = spectrum2D(f,x,y)
% Calculates the 2D spectrum of the input 2D field
%
% Usage:
%   [k,e] = spectrum2D(f,x,y);
%
% Calculates the 2D spectrum of the input field f
%
% Inputs:
%   f - 2D field to be analyzed
%   x - 2D grid of x values
%   y - 2D grid of y values
% Outputs:
%   k - wavenumbers at which the spectrum is calculated
%   e - the spectrum
%
% See also ENERGYSPECTRUM2D, SPECTRUM1D

% TODO: improvements

N = size(f); % size of field
Nr = N(1);Nc = N(2); % get number of rows and columns
[nk,nki] = min(N); % smallest dimension and index
% get physical size of grid

    if ~exist('x')|~exist('y');
        Lx = 1;Ly = 1;
    else
        Lx = max(x(:))-min(x(:));Ly = max(y(:))-min(y(:));
    end %if

L = [Lx Ly];
[kx,ky]=fmodes2(N,L);
kr = sqrt( kx.^2 + ky.^2);
%k = round(k);


%     [jx,jy] = meshgrid([1:Nx],[1:Ny]);
%     %hmsk = ( (1-cos(2*pi*jx/Nx))/2 ).*( (1-cos(2*pi*jy/Ny))/2 );
%     hmsk = ( (1-cos(2*pi*jx/Nx))/2 ).*( (1-cos(2*pi*jy/Ny))/2 ); % hamming-type window
%     f = f.*hmsk; % mask input data

fsig = fft2(f);
Fe = 0.5*(fsig.*conj(fsig))/(Nr*Nc)^2;

%sum(Fe(:))


% generate ks
ks = fmodes(nk,L( mod(nki,2)+1 )); % added 2/27/2007 Jori, fixes wavenumber for non-symmetric matrices
ks = ks(ks>=0);
dks = ks(2)-ks(1); % step size delta k

%tkc = zeros(size(kr));
e = zeros(length(ks),1);
for i = 1:length(ks);
    kc=ks(i); % current wavenumber
    rng = (kr>(kc-dks/2))&(kr<(kc+dks/2));
        if ~isempty(Fe(rng));
            e(i) = kc.*mean(Fe(rng));
%            e(i) = sum(Fe(rng));
        end %if
%        figure(8);
%        imagesc(rng);pause;
%        tkc = tkc + rng;
end %i
e = (2*pi)*e;
%le = sum(Fe(~tkc));% lost energy from corners
k = ks';

% 9/4/2006 Jori
%
% Updates: 2/7/2007 Fixed error calculating spectrum for non-symmetric
% matrices (the dimensions of the matrix were swapped)
% fixed normalization (Nr*Nc)^2