function [n,x] = nmpdf(XX, bins)
% calcuate a normalized PDF using the hist function
%
% Usage:
%   [n,x] = nmpdf(XX, numbins);
%            or
%   [n,x] = nmpdf(XX, xs)
%
% Inputs:
%   XX - input signal   
%   bins - either as numbins - number of bins to use
%               or 
%           xs - locations of the centers of the bins
%
% Returns similar n, x as hist function
%
% i.e. Plotting with
% plot(X,N); or semilogy(X,N);
%
% See also: HIST (matlab function)

% set default number of bins for histogram to 100
if ~exist('bins','var')
    bins = 100;
end %if

[N,x] = hist(XX(:),bins);


% normalize the pdf using trapz
nm = trapz(x,N);
n = N./nm;n=n(:);x=x(:);

% % alternative normalization not using trapz
% dx = diff(x);dn = diff(N);
% t=dx(:).*dn(:);
% %sum(t)
% %whos N x dx dn

%nm

% uses standard matlab functions: hist, std, trapz
% Created 1/20/2006 by Jori
% originally created from function nmpdf.m 12/13/2003 JERF