function [stats] = signalstats(sig)
% Returns statisical quantities of the input signal
%
% Usage:
%   stats = signalstats(sig);
%
% Inputs:
%   sig - signal to be analyzed
%
% Outputs:
%   stats - structure containing statistical quantities
%
% See also: FLAT, SKEW

N = numel(sig); % Number of elements in the signal
mn = mean(sig); % mean of the signal
sd = std(sig); % standard deviation of signal
fl = flat(sig); % flatness of signal
sk = skew(sig); % skewness of signal

disp(['Signal statistics']);
disp(['Number of elements in the signal : N = ',num2str(N)]);
disp(['Mean               : ',num2str(mn,'%0.4f')]);
disp(['Standard deviation : ',num2str(sd,'%0.4f')]);
disp(['Flatness           : ',num2str(fl,'%0.4f')]);
disp(['Skewness           : ',num2str(sk,'%0.4f')]);

stats.N = N;
stats.mean = mn;
stats.std = sd;
stats.flatness = fl;
stats.skewness = sk;