function X = FBMNoise(N,H,sigma,M)
%FBMNOISE generates Fractional Brownian Motion
%
% Uses FGNNoise to generate trajectories of a fractionnal Gaussian
% noise with a given Hurst exponent, and then integrates it to obtain
% fractional Brownian motions. 
%
%  Usage :
%   X = FBMNoise(N, H [,sigma,M])
%
%  Inputs :
%    N - length of trajectories
%    H - Hurst exponent 
%    sigma - standard deviation (default : 1)
%    M - number of trajectories (default : 1)
% 
% Example
%   X = FBMNoise(2^10, 0.75);
%   plot(X);
%
%  Output :
%    X - matrix of size NxM
%
% See also : GaussianCorrNoise, FGNCovariance, FGNNoise

% Version 0.1 RNVY 20/06/07

if(nargin < 3)
    sigma = 1;
end
if(nargin < 4)
    M = 1;
end

if((0 <= H) && (H < 1))
    X = FGNNoise(N, H, sigma, M);
    X = cumsum(X);
else
    error('Should have 0 <= H < 1');
end

end

