function ac = FGNCovariance(N, H, sigma)
%FGNCOVARIANCE covariance function of a fractionnal gaussian noise
%
% Used by FGNNoise
%
% Usage :
%   ac = FGNCovariance(N, H [,sigma])
%
% Inputs :
%   H - Hurst exponent (0 <= H < 1);
%   N - sampling time
%   sigma - variance (default : 1)
% 
% Output :
%   ac - vector of size N, ac(i+1) = E(X(t)*X(t+i))
%
% See also : FGNNoise, GaussianCorrNoise

if(nargin < 3)
    sigma = 1;
end

if((H >= 1) || (H < 0))
    disp('Warning ! Should have 0 <= H < 1');
end

tmp = 0:(N-1);

ac = sigma^2 / 2*((tmp+1).^(2*H) + (abs(tmp-1)).^(2*H) - 2*tmp.^(2*H));

end
