function X = FGNNoise(N,H,sigma,M)
%FGNNOISE generates Fractional Gaussian Noise
%
% Uses GaussianCorrNoise to generate trajectories of a fractionnal Gaussian
% noise with a given Hurst exponent
% 
% Usage :
%   X = FGNNoise(N, H, [sigma, M])
%
% Inputs :
%   N - length of trajectories
%   H - Hurst exponent (0 <= H < 1)
%        1/2 for white noise
%        > 1/2 for long range correlations
%        < 1/2 for anticorrelations
%   sigma - standard deviation (default : 1)
%   M - number of trajectories (default : 1)
%
% Output :
%   X - matrix of size NxM
%
% Example
%   X = FGNNoise(2^10, 0.75);
%   plot(X);
%
% See also : GaussianCorrNoise, FGNCovariance, FBMNoise

% Version 0.1 RNVY 20/06/07

if(nargin < 3)
    sigma = 1;
end
if(nargin < 4)
    M = 1;
end

if((0 <= H) && (H < 1))
    ac = FGNCovariance(N,H,sigma);
    X = GaussianCorrNoise(ac, M);
else
    error('Error ! Should have 0 <= H <= 1');
end
end

