function X = GaussianExpNoise(N,lambda ,sigma ,M)
%GAUSSIANEXPNOISE generates a Gaussian process with exponential covariance
% 
% Uses the integral method described in :
% Fast, accurate algorithm for numerical simulation of 
% exponentially correlated colored noise, R.Fox et al, PRA 38 (1988))
%
% Usage : 
%    X = GaussianExpNoise(N,tau [,sigma [,M]])
%
% Inputs :
%   N - sampling time
%   tau - correlation time (in number of samples)
%   sigma - standard deviation (default : 1)
%   M - number of trajectories (default : 1)
%
% Example
%   X = GaussianExpNoise(1024, 10); plot(X);
%
% See also : FGNNoise, GaussianCorrNoise
%

% Version 0.1 RNVY 20/06/07

if(nargin < 3)
    sigma = 1;
end
if(nargin < 4)
    M = 1;
end

X = randn(N,M);
E = exp(-1/lambda);
sigma2 = sigma*sqrt((1-E^2));
X(1,:) = X(1,:)*sigma;
X(2:N,:) = X(2:N,:)*sigma2;

for k=2:N
    X(k,:) = X(k-1,:)*E + X(k,:);
end

end
