function F = RandStepSaw(N,k, type)
%RANDSTEPSAW generates a random multi-step or sawtooth signal
%
% The signal is normalised to have zero mean and variance 1.
% If the number of singularities is big, it can look quite pathological
%
% Usage :
%   F = RandRampSaw(N, k, type)
%
% Inputs :
%   N - sampling time
%   k - number of singularities (steps or teeth)
%   type - 'step' or 'saw'
% 
% Output :
%   F - vector representing the function
%
% Example
%   F = RandStepSaw(1024, 3, 'saw');
%   plot(F);
%
% See also : RandWC, RandWCBesov

%
% Version 0.1 RNVY 20/06/07

if ~(strcmp(type,'step') || strcmp(type,'saw'))
    error('type must be step or saw');
end
F = zeros(1,N);
% Tirage de la fonction
disc = sort(rand(1,k));
disc_idx = 1;
signe = 1;
for x = 1:N
    if((disc_idx <= k) && (x > N*disc(disc_idx)))
        disc_idx = disc_idx + 1;
        signe = -rand*sign(signe);
    end %if
    F(x) = signe;
end %for x

F = F - mean(F);

if strcmp(type,'saw')
    if(F ~= 0)
        F = cumsum(F);
    end
end

F = F/sqrt(sum(F.^2)/N);
end