function Re = localRe2D(wcVx,wcVy,x,ls)
% 2D Local Reynolds number calculated from 2D CWT coefficients of velocity
%
% Usage:
%   Re = localRe2D(wcVx,wcVy,x,ls);
%
% The velocity should be given in cm/s. 
% The kinematic viscosity is taken to be 0.01 cm^2/s.
%
% Inputs:
%   wcVx - 2D CWT wavelet coefficients of x-component of velocity
%   wcVy - 2D CWT wavelet coefficients of y-component of velocity
%   x  - linear position
%   ls - length scales (real physical space values)
%
% Outputs:
%    Re - local Reynolds number

	% Constants
	nu = 0.01; % approximate kinematic viscosity of water
	Cpsi = pi; % wavelet constant // check this value for the complex morlet


% First calculate the RMS velocity from the wavelet coefficients
% of the CWT of the components

rmsV = sqrt( (1/2/Cpsi) * wcVx.*conj(wcVx) + wcVy.*conj(wcVy) );

% dispose of variables wcVx and wcVy to save memory (no longer needed)
clear wcVx wcVy;

% Calculate the Reynolds number
for i = 1:length(ls); % loop through scales
	Re(i,:,:) = rmsV(i,:,:)*ls(i)/nu;
end %i

end

% Created 10/18/2006 Jori
