function [ks,ew] = waveletspectrum2D(sig,x,y);
% Calculate the 2D wavelet spectrum of a signal
%
% Usage:
%	[k,E] = waveletspectrum2D(sig,x);
%
% Inputs:
%	sig - 2D signal
%	x - 2D matrix of x values
%	y - 2D matrix of y values
% Outputs:
%	ks - wavenumbers
%	ew - spectral energy density as a function of wavenumbers ks
%
% See also: WAVELETSPECTRUM1D

[Nr,Nc] = size(sig);

if ~exist('x','var'); % if the x input is not specified
    x = [0:Nc-1]/Nc; % domain size = 1 [0,1)
    L = 1;
    dx = 1;
else
    L = max(x(:)) - min(x(:)); % size of domain
    dx = x(1,2)-x(1,1); % spacing
end %if

as = cwscale([1:Nc/2],'k2a'); % dilation parameters, based upon Fourier modes
nscales = length(as);

ks = cwscale(as,'a2k'); % convert the dilation parameters used into frequencies
ks = ks/L;

thetas = pi*[0:11]/12; % 12 angles of morlet wavelet to average over

% loop over scales in the decomposition
% take the 1D CWT, one scale/dilation at a time so that we don't encounter
% memory problems

ew = zeros(1,nscales);

for i=1:nscales
    a = as(i);
    for th = 1:length(thetas);
         theta = thetas(th);
         coef2D = cwt2d(sig, a, theta);
         ew(i) = ew(i) + sum(abs(coef2D(:)).^2)  
    end %th angle loop
    ew(i) = ew(i).*ks(i) / length(thetas);
end %i

% 2/23/2007 Jori
% Code cleaned up 11/08/2012 RNVY
