function [scalesout] = cwscale(scalesin,ctype);
% Conversion between various types of scales of the continuous wavelet
%
% Usage:
%   scalesout = cwscale(scalesin,ctype);
%
% Input:
%   scalesin - scale(s) to be converted
%   ctype - conversion type, 'a2sc','a2k','sc2a','sc2k','k2sc','k2a'
%
% Output:
%   scalesout - the converted scales out
%
% See also: CWSCALES

% for now only implement the complex Morlet wavelet

wavelet_toolbox_config;

if(~strcmp(wtype,'cmorl'))
	error('Only the Morlet wavelet is implemented');
end

switch ctype
    
    case 'a2sc' % convert dilation parameter to scale
        scalesout = scalesin/a_sc1;
        
    case 'a2k' % convert dilation parameter to wavenumber
        scalesout = kpsi./(2*pi*scalesin);

    case 'sc2a' % convert scale to dilation parameter
        scalesout = a_sc1*scalesin;
        
    case 'sc2k' % convert scale to wavenumber
        scalesout = kpsi./(2*pi*a_sc1*scalesin);
        
    case 'k2a' % convert wavenumber to dilation parameter
        scalesout = kpsi./(2*pi*scalesin);
        
    case 'k2sc' % convert wavenumber to scale
        scalesout = kpsi./(2*pi*a_sc1*scalesin);
      
    otherwise 
        disp(['Unknown conversion type: ',ctype]);return;
        
end % switch


% Created 5/16/2006 Jori
