function [scalesout] = cwscales(numoct,nvpo)
% Returns the scales given the number of octaves and voices per octave
%
% Usage:
%   scalesout = cwscales(numoct,nvpo);
%
% Input:
%   numoct - the number of octaves in signal (i.e. signal length = 2^J)
%   nvpo - the number of voices per octave
%
% Output:
%   scalesout - the converted scales out
%
% Example: 
%
%   numoct = 7; % for a signal length 2^7 = 128
%   nvpo = 4;
%   scalesout = cwscales(numoct,nvpo);
%   ks = 1./scalesout; % Fourier wavenumbers (no pi)
%
%   as = cwscale(ks,'k2a');
%   [wc,as] = cwt1d(sig,as,'cmorl','f'); % 1D CWT
%
% See also: CWSCALE, CWT1D, CWT2D

% The following two methods are equilvalent (to within reasonable numerical precision)
    scalesout = 2.^(-[0:numoct*nvpo]/nvpo);
%    scalesout = 2.^-[0:1/nvpo:numoct];


% Created 3/28/2007 Jori