function drawLIF1D(wc,ys,sc)
% Draw the 1D local intermittency factor
%
% Usage:
%   drawLIF1D(I_lx,sig,as);
%
% Inputs:
%   I_lx - local intermittency factor
%   sig  - original signal
%   as   - dilation parameters use in the CWT
%
% Outputs:
%   Creates a plot of the local intermittency factor in space and scale
%   calculated from the intfact coefficients using the pcolor function
%
% See also: INTFACTOR1D, DRAWCWT1D, CWT1D

N = length(ys);
xs = [0:N - 1]*(1/N); % periodic domain from [0,1)

% Energy spectrum of signal
%    [E,k] = periodogram(ys,xs); 
    [E,k] = spectrum1D(ys,xs); 
% wavelet scalogram
%    sg = mean(wc.*conj(wc),2);
%    sg = mean(wc.*conj(wc),1);
       
    kpsi = 6; % default = 6 !!
%    kpsi = 3;
    ks = kpsi/2/pi./sc; % the equivalent wavenumbers that the CWT is calculated at
    dxs = N./ks; % scale in terms of dx unit grid spacing
%    dxs = N*cwscale(sc,'a2sc'); % scale in terms of dx unit grid spacing, added 2/6/2007 Jori

    amin = 2*kpsi/pi/N; % minimum dilation before we should anti-alias
    
    load cmorl_COI.mat
% convert the COI to units of dxs
    dxsCOI(2,:) = N./COI(2,:);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Draw Intermittency factor %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;set(gcf,'visible','off');
%    H = pcolor(xs,ks,abs(wc));set(H,'linestyle','none');set(gca,'YScale','log');
    H = pcolor(xs,dxs,abs(wc));set(H,'linestyle','none');set(gca,'YScale','log');set(gca,'YDir','reverse');
    PCAX = gca;
%    hold on;C1=semilogy(COI(1,:),COI(2,:),'-k');hold on;set(C1,'LineWidth',2);
    hold on;C1=semilogy(COI(1,:),dxsCOI(2,:),'-k');hold on;set(C1,'LineWidth',2);
    L=line([0 1],[N/cwscale(amin,'a2k') N/cwscale(amin,'a2k')]);set(L,'color','k','LineWidth',2);
    
    set(gca,'YAxisLocation','Right');
    CA = gca;load mod_colormap.mat;colormap(c);
    CB=colorbar('horizontal');set(CB,'tickdir','out');
    xlabel(CA,'Position');
    ylabel('k  (1/length)');
%    ylabel(CA,'a  (dilation parameter)');
    ylabel(CA,'\Delta x (grid spacing)');set(gca,'YDir','reverse');

    set(CA,'outerposition',[0.05 0.05  0.95 0.95])
    P1 = get(CA,'position');
    set(CA,'position',[P1(1) P1(2)-0.05 P1(3) P1(4)]);
    set(CA,'tickdir','out');
    
    
    % plot the original signal
    NA = axes;
    rotate(NA,[0 0 1],90);   
    set(NA,'position',[P1(1) P1(2)+P1(4)-0.05 P1(3) 0.1]);
% 
    plot(xs,ys);axis([min(xs) max(xs) min(real(ys))-0.05*(max(real(ys))-min(real(ys))) max(real(ys))+0.05*(max(real(ys))-min(real(ys)))])
    set(gca,'xticklabel','');set(gca,'yticklabel','');


axes(NA);
set(NA,'ActivePositionProperty','Position'); % preserve position when resizing figure window
set(CA,'ActivePositionProperty','Position'); % preserve position when resizing figure window
% %set(NA,'DataAspectRatioMode','manual');

% plot the spectral energy
NA2 = axes; % new axis
    loglog(k,E,'k');hold on;
%    set(NA2,'Yscale','linear'); % commented 2/6/2007 Jori
    psc = (sc/N)*2*pi; % physical scales
    %psc = (sc/N); % physical scales
    psck = 1./(psc);
    %axis([min(psck) max(psck) min(E) max(E)]);
    %axis([min(sc/N) max(sc/N) min(E) max(E)]);
%    axis([min([ks(:);k(:)]) max([ks(:);k(:)]) min([E(:);sg(:)]) max([E(:);sg(:)])]);
    axis([min([ks(:)]) max([ks(:)]) min([E(:)]) max([E(:)])]);

    set(NA2,'position',[P1(1)-0.1 P1(2)-0.05 0.1 P1(4)]);

    %set(NA2,'XAxisLocation','top');
    set(NA2,'XDir','reverse');
    set(NA2,'YDir','reverse');
%    set(NA2,'xticklabel','');
    set(NA2,'xaxislocation','bottom')
    set(NA2,'yticklabel','');
    set(NA2,'CameraUpVector',[1 0 0]);

    XL=xlabel(NA2,'k');
    set(XL,'rotation', [90]);
    set(XL,'horizontalalignment','right');
    set(XL,'verticalalignment','bottom'); 
    Pxl = get(XL,'position');

    axes(PCAX); % make the pcolor axis current
    
% Created 3/28/2007 Jori
% from drawCWT1D