%AFWT
function strsig = AFWT(strsig, qmf, nscales)

if(isempty(strsig.topo))
    if(nargin < 3)
        strsig = FWT(strsig, qmf);
    else
        strsig = FWT(strsig, qmf, nscales);
    end
    return;
end

level = strsig.level;
Jmax = strsig.Jmax;

if(nargin < 3)
    nscales = Jmax - level;
end

g = qmf;
h = fliplr(MirrorFilt(g));
U = mixed_level_filters(g);
l_U = length(U);
overrun = (length(g)-2)/2;


for l = level:level+nscales-1
    
    [phi, pos_phi] = get_adaptive_phi(strsig, Jmax-l);
    
    if(~isempty(phi{1}))
        save_1 = phi{1}(mod((1:2*overrun)-1, length(phi{1}))+1);
    end
        
    
    for idx = 1:length(phi)
        if(bitand(pos_phi(idx),2) && bitand(pos_phi(1),1)) % we are at the end and need to take periodicity into account
            tmp = cat(1, phi{idx}, save_1);
            tmp_phi = aconv(g,tmp')';
            tmp_psi = aconv(h,tmp')';
            lg = numel(phi{idx});
            phi{idx}(1:2:end) = tmp_phi(1:2:lg);
            phi{idx}(2:2:end) = tmp_psi(1:2:lg);
            
        else
            tmp_phi = aconv(g,phi{idx}')';
            tmp_psi = aconv(h,phi{idx}')';
            tmp_tail = phi{idx}(end - l_U+1:end);

            phi{idx}(1:2:end) = tmp_phi(1:2:end);
            phi{idx}(2:2:end) = tmp_psi(1:2:end);

            phi{idx}(end - l_U+1:end) = U * tmp_tail;
        end
    end
    
    strsig = set_adaptive_phi(phi, strsig, Jmax-l);
end

strsig.level = level + nscales;

end
%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
