%AIWT
function strsig = AIWT(strsig, qmf, nscales, qmf_tilde)


if(isempty(strsig.topo))
    if(nargin < 3)
        strsig = IWT(strsig, qmf);
    else
        strsig = IWT(strsig, qmf, nscales);
    end
    return;
end

level = strsig.level;
Jmax = strsig.Jmax;

g = qmf;

if(nargin < 4)
    h = fliplr(MirrorFilt(g));
else
    h = qmf_tilde;
end

even = h;
odd = g;
even(2:2:end) = g(1:2:end);
odd(1:2:end) = h(2:2:end);

overrun = (length(g)-2)/2;

if(nargin < 3)
    nscales = level;
end

for l = level-1:-1:level-nscales

    [phipsi, pos_phi] = get_adaptive_phi(strsig, Jmax-l, overrun);

    for idx = 1:length(phipsi)
        if(bitand(pos_phi(idx),1) && bitand(pos_phi(end),2)) % we are on the left and need to take periodicity into account
            tmp = cat(1, phipsi{end}, phipsi{idx});
            
            tmp_even = fliplr(aconv(even,fliplr(tmp')))';
            tmp_odd =  fliplr(aconv(odd,fliplr(tmp')))';
            
            lg = numel(phipsi{idx});
            tmp_even = tmp_even(end-lg+1:end);
            tmp_odd = tmp_odd(end-lg+1:end);
            
            phipsi{idx}(1:2:end) = tmp_even(2:2:end);
            phipsi{idx}(2:2:end) = tmp_odd(2:2:end);
        else
            tmp_even = fliplr(aconv(even,fliplr(phipsi{idx}')))';
            tmp_odd = fliplr(aconv(odd,fliplr(phipsi{idx}')))';

            phipsi{idx}(1:2:end) = tmp_even(2:2:end);
            phipsi{idx}(2:2:end) = tmp_odd(2:2:end);
            phipsi{idx} = phipsi{idx}(2*overrun+1:end);
        end %if
        
    end %for idx

    strsig = set_adaptive_phi(phipsi, strsig, Jmax-l);
end %for l

strsig.level = level - nscales;

end %function
%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
