%APPLY_ALL_SHIFTS
function strsig = apply_all_shifts(strsig, shift_indic)
% The goal of this function is to apply all the displacements of wavelet
% coefficients in a single pass, by moving each coefficient ONCE at
% most.
%
% RNVY 28/08/2008

% the things that we will modify
sig = strsig.sig;
topo1 = strsig.topo(:,1) - 1;

% change referential
shift_indic = sortrows(shift_indic);
shift_indic = shift_indic';
shift_indic(1,:) = shift_indic(1,:)-1;

%aggregate redundant shifts
idx1 = 1;
idx2 = 2;
while(idx2 < size(shift_indic, 2))
    if(shift_indic(1,idx1) == shift_indic(1,idx2))
        shift_indic(2,idx1) = shift_indic(2,idx1) + shift_indic(2,idx2);
        shift_indic(2,idx2) = 0;
        idx2 = idx2 + 1;
    else
        idx1 = idx2;
        idx2 = idx2 + 1;
    end
end
shift_indic = shift_indic(:,shift_indic(2,:) ~= 0);

% convert piece-wise constant shift indicator to source/target anchors
shift_list0 = shift_indic*0;
shift_list0(1,:) = shift_indic(1,:); % we already have the source
% the first anchor is always fixed
shift_list0(2,1) = shift_list0(1,1);
toto = cumsum(shift_indic(2,1:end-1));
shift_list0(2,2:end) = shift_list0(1,1) + cumsum(2.^(toto).*diff(shift_indic(1,:)));
%insert fixed anchors when the shift direction reverses
bad = find(abs(diff(sign(diff(shift_list0)))) >= 2);
l1 = shift_list0(1,bad+1)-shift_list0(1,bad);
l2 = shift_list0(2,bad+1)-shift_list0(2,bad);
fixed = (shift_list0(2,bad).*l1 - shift_list0(1,bad) .*l2) ./ ( l1-l2 ) ;
shift_list0 = cat(2, shift_list0, cat(2,[fixed;fixed]));
shift_list0 = sortrows(shift_list0')';

if(shift_list0(1,end) ~= shift_list0(2,end))
    error('Invalid shift list');
end
    
% convert source/target anchors to source/target intervals
shift_list1 = shiftdim(shift_list0(:,1:end-1), -1);
shift_list2 = shiftdim(shift_list0(:,2:end), -1);
shift_list = cat(1, shift_list1, shift_list2);
shift_list = shift_list(:,:,shift_list(2,1,:) - shift_list(1,1,:) ~= 0);
all_strides = squeeze((shift_list(2,2,:) -  shift_list(1,2,:)) ./ (shift_list(2,1,:) - shift_list(1,1,:))) ;

%[all_strides, S] = sort(all_strides);
%shift_list = shift_list(:,:,S);

% change order of transformations
fixed_start = find(shift_list(1,2,:) == shift_list(1,1,:));
fixed_stop = find(shift_list(2,2,:) == shift_list(2,1,:));

reverse = find(shift_list(2,2,fixed_start(:)) > shift_list(2,1,fixed_start(:)));

for idx = 1:length(reverse)
   toto =  (fixed_start(reverse(idx)):fixed_stop(reverse(idx)));
   shift_list(:,:,toto) = shift_list(:,:,fliplr(toto));
   all_strides(toto) = all_strides(fliplr(toto));
end

% now apply the shifts !
for idx = 1:numel(all_strides)

    tgt_start = shift_list(1,2,idx);
    tgt_stop = shift_list(2,2,idx);
    src_start = shift_list(1,1,idx);
    src_stop = shift_list(2,1,idx);

    stride = all_strides(idx);

    if(stride < 1) % contract

        if(mod(1/stride,1))
            error('non integer stride');
        end
        sig( (tgt_start+1):tgt_stop ) = sig( (src_start+1):(1/stride):src_stop );


    elseif(stride == 1) % translate

        sig( (tgt_start+1):tgt_stop ) = sig( (src_start+1):src_stop );

    elseif(stride > 1)  % dilate
        if(mod(stride,1))
            error('non integer stride');
        end
        tmp = sig( (src_start+1):src_stop );
        sig( (tgt_start+1):tgt_stop ) = 0;
        sig( (tgt_start+1):stride:tgt_stop ) = tmp;

    end

    idxtopo = ((topo1 >= (src_start)) & topo1 < src_stop);
    topo1(idxtopo) = stride * ( topo1(idxtopo)-src_start )  + tgt_start ;

end %for

strsig.sig = sig;
strsig.topo(:,1) = topo1 + 1;
strsig.topo = sortrows(strsig.topo);

end %function

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
