%GET_ADAPTIVE_PHI Retrieves scaling function coefficients based on tree descriptor
function [phi,pos_phi] = get_adaptive_phi(strsig, j, overrun)

% meaning of pos_phi
% 0 : no boundaries
% 1 : boundary on the left
% 2 : boundary on the right
% 3 : boundary on both sides

% overrun > 0 indicates that one is doing an inverse
% wavelet transform and therefore needs an apron on the left of each zone

if(nargin < 3)
	overrun = 0;
end
    
J = strsig.J0;
b = 1;
signal = strsig.sig(:);
%N = length(signal);
idx = 0;
phi = cell(1,1);
b_last = 0;
offset = 0;
topo = strsig.topo;
pos_phi = [];

for n = 1:size(topo,1)
    a = b;
    b = topo(n,1);
    stride = 2^(J-j);
    
    if(j <= J)
        if(a == b_last)
            phi{idx} = cat(1, phi{idx}, signal(a+offset:stride:b-1));
            rem = mod(b - a - offset,stride);
            if(rem == 0)
                offset = 0;
            else
                offset = stride - rem;
            end
        else    
            idx = idx + 1;
            phi{idx} = signal(a:stride:b-1);
            if(overrun)
               toto =  zeros(2*overrun,1);

               if(a ~= 1 && topo(1,1) ~= 1)
                   % in this case we should have stride == 1
                   if(stride ~= 1)
                       error('oups');
                   end
                   if(a-overrun > 0)
                       toto(1:2:2*overrun) = signal(a-overrun:a-1);
                       phi{idx} = cat(1, toto, phi{idx});
                   else
                       fprintf('hum\n');
                       toto(2*overrun-(a-1)/stride+1:2:2*overrun) = signal(1:stride:a-stride);
                       toto{idx}(1:2:2*overrun-2*a+2) = signal(end-stride*overrun-a:stride/2:end);
                       phi{idx} = cat(1, toto, phi{idx});
                   end
               end
            end
            if(a == 1)
                pos_phi(idx) = 1;
            else
                pos_phi(idx) = 0;
            end
            
            rem = mod(b - a,stride);
            if(rem == 0)
                offset = 0;
            else
                offset = stride - rem;
            end
        end
        b_last = b;
    end

    offset = offset * 2^(topo(n,2));
    J = J + topo(n,2);

end %for

a = b;
b = numel(signal);

if(j <= J)
    stride = 2^(J-j);
    
    if(a == b_last)
        phi{idx} = cat(1, phi{idx}, signal(a+offset:stride:b));    
    else
        idx = idx + 1;
        phi{idx} = signal(a:stride:b);
        
        if(overrun)
            toto =  zeros(2*overrun,1);

            if(a ~= 1 || topo(1,1) ~= 1)
                if(a-overrun > 0)
                    toto(1:2:2*overrun) = signal(a-overrun*stride:stride:a-stride);
                    phi{idx} = cat(1, toto, phi{idx});
                else
                    toto(2*overrun-(a-1)/stride+1:2:2*overrun) = signal(1:stride:a-stride);
                    toto{idx}(1:2:2*overrun-2*a+2) = signal(end-stride*overrun-a:stride/2:end);
                    phi{idx} = cat(1, toto, phi{idx});
                end
            end
        end

    end

    if(isempty(pos_phi))
        pos_phi = 3;
    elseif(numel(pos_phi) >= idx)
        pos_phi(idx) = pos_phi(idx) + 2;
    else
        pos_phi(idx) = 2;
    end
end
    

end %function
%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
