%% First tests for 1D adaptive wavelet transform.

J = 10;
N = 2^J;
F = MakeSignal('Piece-Regular', N);
x = 0:1/N:1-1/N;

g = MakeONFilter('Daubechies',4);
h = fliplr(MirrorFilt(g));

even = h;
odd = g;
even(2:2:end) = g(1:2:end);
odd(1:2:end) = h(2:2:end);

F0 = F;

for l = 0:J-1
   
    phi = F0(1:2^l:end);
    
    F0(1:2^(l+1):end) = DownDyadLo(phi, g);%aconv(g, phi);
    F0(1+2^(l):2^(l+1):end) = DownDyadLo(phi, h);
      
end

%%
FR = F0;
for l = J:-1:1
   
    phipsi = FR(1:2^(l-1):end);
%    psi = y(1+2^l:2^(l):end);
    
  tmp_even = iconv(even,lshift(phipsi));
  tmp_odd = iconv(odd,lshift(phipsi));
            
 FR(1:2^(l):end)  = tmp_even(1:2:end);
 FR(1+2^(l-1):2^(l):end) = tmp_odd(1:2:end);
  %  FR(1:2^(l):end) = DownDyadHi(phipsi, MirrorFilt(even));%aconv(g, phi);
  %  FR(1+2^(l-1):2^(l):end) = DownDyadHi(phipsi, MirrorFilt(odd));
      
end

%%
J = 11;
N = 2^J;
F = MakeSignal('Piece-Regular', N);
x = 0:1/N:1-1/N;

F1 = [F(1:2:N/4) F(N/4+1:N/2) F(N/2+1:2:end)];
x1 = [x(1:2:N/4) x(N/4+1:N/2) x(N/2+1:2:end)];

desc.J0 = J-1;
desc.topo = [N/8+1, 1; N/8+N/4+1, -1];

%%
F2 = F1;
Jmax = J;
U = mixed_level_filters2(g);
l_U = length(U);

for l = 0:Jmax-1
    
    [phi, pos_phi] = get_adaptive_phi(F2, Jmax-l, desc);
    
    for idx = 1:length(phi)
        if(bitand(pos_phi(idx),2) && bitand(pos_phi(1),1)) % we are at the end and need to take periodicity into account
            tmp = cat(1, phi{idx}, phi{1});
            tmp_phi = aconv(g,tmp')';
            tmp_psi = aconv(h,tmp')';
            lg = numel(phi{idx});
            phi{idx}(1:2:end) = tmp_phi(1:2:lg);
            phi{idx}(2:2:end) = tmp_psi(1:2:lg);
            
        else
            tmp_phi = aconv(g,phi{idx}')';
            tmp_psi = aconv(h,phi{idx}')';
            tmp_tail = phi{idx}(end - l_U+1:end);

            phi{idx}(1:2:end) = tmp_phi(1:2:end);
            phi{idx}(2:2:end) = tmp_psi(1:2:end);

            phi{idx}(end - l_U+1:end) = U * tmp_tail;
        end
    end
    
    F2 = set_adaptive_phi(phi, F2, Jmax-l, desc);
end

%%

overrun = l_U;
FR2 = F2;
clear phi;

for l = Jmax-1:-1:0
    
     [phipsi, pos_phi] = get_adaptive_phi(FR2, Jmax-l, desc, overrun);
%    psi = y(1+2^l:2^(l):end);
    
%    FR(1:2^(l):end) = DownDyadHi(phipsi, MirrorFilt(even));%aconv(g, phi);
%    FR(1+2^(l-1):2^(l):end) = DownDyadHi(phipsi, MirrorFilt(odd));
    
%    [phi, pos_phi] = get_adaptive_phi(F2, Jmax-l, desc);
    
    for idx = 1:length(phipsi)
        if(bitand(pos_phi(idx),1) && bitand(pos_phi(end),2)) % we are on the left and need to take periodicity into account
            tmp = cat(1, phipsi{end}, phipsi{idx});
            tmp_even = iconv(even,lshift(tmp'))';
            tmp_odd = iconv(odd,lshift(tmp'))';
            lg = numel(phipsi{idx});
            phipsi{idx}(1:2:end) = tmp_even(1:2:lg);
            phipsi{idx}(2:2:end) = tmp_odd(1:2:lg);
            
        else
            tmp_even = iconv(even,lshift(phipsi{idx}'))';
            tmp_odd = iconv(odd,lshift(phipsi{idx}'))';
            
            phipsi{idx}(1:2:end) = tmp_even(1:2:end);
            phipsi{idx}(2:2:end) = tmp_odd(1:2:end);
            phipsi{idx} = phipsi{idx}(2*overrun+1:end); 
        end
    end
    
    FR2 = set_adaptive_phi(phipsi, FR2, Jmax-l, desc);
end




%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
