%% First tests for 1D adaptive wavelet transform.

%% Non adaptive transform
J = 10;
N = 2^J;
%F1.sig = MakeSignal('Leopold', N);
F1.sig = zeros(1,N);
F1.sig(N/4+N/16:N/2-N/16) = 1;
F1.level = 0;
x1 = 0:1/N:1-1/N;

qmf = MakeONFilter('Daubechies',6) ;

F1_t = FWT(F1, qmf);
F1_r = IWT(F1_t, qmf);

%% Adaptive transform with only one level of refinement
J = 13;
N = 2^J;
%tmp = MakeSignal('Piece-Regular', N)';
%tmp = zeros(N,1);
%tmp(N/4+N/16:N/2-N/16) = 1;
tmpx = 0:1/N:1-1/N;
x2 = [tmpx(1:2:N/4) tmpx(N/4+1:N/2) tmpx(N/2+1:2:end)];

F2.sig = [tmp(1:2:N/4) ;tmp(N/4+1:N/2); tmp(N/2+1:2:end)];
F2.level = 0;
F2.J0 = J-1;
F2.Jmax = J;
F2.topo = [N/8+1, 1; N/8+N/4+1, -1];
x = make_awt_grid(F2);
F2.sig = sin(2*pi*x)';

F2_t = AFWT(grid_to_wt(F2), qmf);
F2_r = wt_to_grid(AIWT(F2_t, qmf));


%%
clf;
plot(x2, F2.sig);
hold all;
plot(x2, F2_r.sig);

%% Insert a superflous high resolution zone
F4_t = F2_t;
tmp = F2_t.sig;
F4_t.sig = zeros(length(F2_t.sig)+16,1);
F4_t.sig(1:4096) = tmp(1:4096);
F4_t.sig(4097:2:4128) = tmp(4097:4112);
F4_t.sig(4129:end) = tmp(4113:end);
F4_t.topo = cat(1,F2_t.topo, [4097, 1; 4129,-1]);

F4_r = wt_to_grid(AIWT(F4_t, qmf));
F4_grid = make_awt_grid(F4_r);
plot(F4_grid, F4_r.sig);

%% Reorganize the tree of wavelet coefficients
G = (length(qmf) - 2)/2;

F3_t = adapt_wt_tree(F4_t, G, 0.001, 0.001);

F3_r = wt_to_grid(AIWT(F3_t, qmf));
grid = make_awt_grid(F3_r);
plot(grid, F3_r.sig);

%% Test dynamic adaptation with a shrinking gaussian

T = 13;
J0 = 10;
N0 = 2^J0;
f = @(x,s) 1./(sqrt(2*pi).*s).*exp(-(x-0.5).^2./(2.*s.*s));
x = 0:1/N0:1-1/N0;
sigma = 1/8;
clear F;
F.sig = f(x,sigma);

qmf = MakeONFilter('Daubechies', 8);
%qmf = fliplr([3.858077774788675e-02, -1.269691253962052e-01, -7.716155549577350e-02, 6.074916413856841e-01, 7.456875589344343e-01, 2.265842651970686e-01]);
%G = (length(qmf)-2)/2;
G = 4;
epsilon = 0.001;
F = wt_to_grid(grid_to_wt(F));
%%
for t = 1:T
fprintf('t = %i, sigma = %g\n', t, sigma);

%sigma = 1/(8*t);
sigma = sigma/1.3;
x = make_awt_grid(F);
F.sig = f(x, sigma);

cla;

plot(x,F.sig, 'r--');
hold on;

F_t1 = AFWT(grid_to_wt(F), qmf);
F_r1 = wt_to_grid(AIWT(F_t1, qmf));

F_t2 = adapt_wt_tree(F_t1, G, epsilon);
F_r2 = wt_to_grid(AIWT(F_t2, qmf));
x2 = make_awt_grid(F_r2);

plot(x,F_r1.sig, 'b+-');
plot(x2,F_r2.sig, 'g+-');

F = wt_to_grid(AIWT(F_t2, qmf));
pause(0.1);



end %for

%% Test adaptive DTCWT
biort = [0.230377813308896, 	0.714846570552916, 	0.630880767929859, 	-0.027983769416860, 	-0.187034811719093, 	0.030841381835561, 	0.032883011666885, 	-0.010597401785069];
qshift = [0.051130405283832, 	  -0.013975370246889, 	  -0.109836051665971, 	   0.263839561058938, 	   0.766628467793037, 	   0.563655710127052, 	   0.000873622695217, 	  -0.100231219507476, 	  -0.001689681272528, 	  -0.006181881892116];
F_t = AFDTCWT(grid_to_wt(F), biort, qshift);
F_r = wt_to_grid(AIDTCWT(F_t, biort, qshift));

x = make_awt_grid(F);
plot(x, F.sig, 'k--');
hold all;
plot(x, F_r.sig, 'r');
%% Test derivation in adaptive wavelet bases.
f_prime = @(x,s) f(x,s) .* (-2) .*(x-0.5) ./ (2.*s.*s);
F_r2 = wt_to_grid(AIDTCWT_prime(F_t, qshift, qshift));
d = 2.^(F_r2.Jmax+1).*F_r2.sig;
plot(x, 2.^(F_r2.Jmax+1).*F_r2.sig);
fplot(@(x) f_prime(x,sigma), [0,1]);

%%
x1 = load('/tmp/x1.out');
x2 = load('/tmp/x2.out');
f1 = load('/tmp/f1.out');
f2 = load('/tmp/f2.out');

%% 
x = load('/tmp/toto2.out'); 
v = load('/tmp/toto1.out'); 
%%
for i = 1:size(x,1)
    plot(x(i,:), v(i,:), 'r+- ');
    pause(0.1);
end


%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
