% Perform an OWT analysis of the input signal
% Note: the length of the signal must be 2^n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Statistics of the field %
stats=signalstats(sig);
N = stats.N; % length of the signal
mn = stats.mean;
sd = stats.std;
fl = stats.flatness;
sk = stats.skewness;

%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Display the data
[miny maxy] = plotlimits(sig);
figure;%set(gcf,'visible','off');
    plot(sig);axis([0 numel(sig) miny maxy]);
    xlabel('Sample number');ylabel('Signal value');title('Signal');

    if N>1000;
        % Make a close-up plot of the signal
        figure;%set(gcf,'visible','off');
            st = N/2-350;ed = N/2+350;
            [miny maxy] = plotlimits(sig(st:ed));
            plot(sig);axis([st ed miny maxy]);
            xlabel('Sample number');ylabel('Signal value');title('Close-up of signal');
    end %if


%% Take the OWT of the signal
% Here we take the orthogonal wavelet transform of the signal.
    qmf=makeonfilter('Coiflet',2); % use Coiflet
    wc=FWT_PO(sig,0,qmf);    % take the wavelet transform

     % Plot the coefficients
    plot(wc);
    [miny maxy] = plotlimits(wc);
    axis([0 N miny maxy]);
    xlabel('Coefficient number');ylabel('Wavelet coefficient value');
    
    % Calculate the PDF of the coefficients
    [Psig,Xsig] = nmpdf(sig(sig~=0)); 	% estimate the PDF of the signal
    [Pwc,Xwc] = nmpdf(wc(wc~=0)); % estimate the PDF of the coefficients
    % Plot the PDF of the coefficients
    figure;%set(gcf,'visible','off');
    semilogy(Xwc,Pwc,'r');hold on; % wavelet coefficient PDF
    semilogy(Xsig,Psig,'b'); % signal PDF
	xlabel('Value');ylabel('Probability');legend('Wavelet PDF','Signal PDF');


%% Plot the coefficients in physical space
    [Scaling_coef,Coefs]=dwt_levels1D(wc);
    drawDWT1D(Coefs,5);drawDWT1D(Coefs,8);
    drawDWT1D(Coefs,11);drawDWT1D(Coefs,14);
%%%%%%%%%%%%%%%%%%%%%

%% Plot correlation of coefficients and signal
    
    C=corr_f(sig); % autocorrelation of signal
    figure;%set(gcf,'visible','off');
    plot( ([0:length(sig)-1]/length(sig)) ,C/C(1),'.-g');hold on;axis([0 0.03 -0.5 1]);
    %axis([0 0.06 -0.5 1]);
    xlabel('Separation (fraction of total interval)');ylabel('Correlation');
    CLs = {'--*k','--*b','--*m','--*y'};i=0;
    for Js=[5 8 11];
        i=i+1;
            Cw=corr_f(Coefs{Js}); % Correlation function of wavelet coefficients
            plot( ([0:2^(Js-1)-1])/2^Js , Cw/Cw(1) ,CLs{i});
    end % Js for loop
    legend('Signal','J=5','J=8','J=11','J=14');
%%
% Plot the correlation as a function of the minimum spacing to next correlation value.
        figure;%set(gcf,'visible','off');
    plot( C/C(1),'.-g');hold on;axis([0 128 -0.5 1]);
    %axis([0 0.06 -0.5 1]);
    xlabel('Separation (smallest dx)');ylabel('Correlation');
    CLs = {'--*k','--*b','--*m','--*y'};i=0;
    for Js=[5 8 11];
        i=i+1;
            Cw=corr_f(Coefs{Js}); % Correlation function of wavelet coefficients
            plot( Cw/Cw(1) ,CLs{i});
    end % Js for loop
    legend('Signal','J=5','J=8','J=11','J=14');
 
%% Coherent - incoherent splitting of the signal
% Here we split the signal into coherent and incoherent components.

    [coh,Nc]=extract1D(sig); % extract coherent component
    inc = sig - coh; % incoherent component

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Statistics of the split field %
mncoh = mean(coh);mninc = mean(inc); % mean of the coherent and incoherent component
sdcoh = std(coh);sdinc = std(inc); % standard deviation of the coherent and incoherent component
flcoh = flat(coh);flinc = flat(inc); % flatness of the coherent and incoherent component
skcoh = skew(coh);skinc = skew(inc); % skewness of the coherent and incoherent component
disp(['Signal statistics']);

disp(['Number of coefficients retained in the coherent: Nc = ',num2str(Nc), ' / ',num2str(N)]);
disp(['         |  Total  | Coherent | Incoherent ']);
disp(['% Energy |  100%   |   ',num2str(100*(sdcoh/sd)^2,'%0.1f'),'%  |  ',num2str(100*(sdinc/sd)^2,'%0.1f'),'%']);
disp(['Mean     |  ',num2str(mn,'%0.4f'),'|  ',num2str(mncoh,'%0.4f'),'  |  ',num2str(mninc,'%0.4f')]);
disp(['Std dev  |  ',num2str(sd,'%0.4f'),' |  ',num2str(sdcoh,'%0.4f'),'  |  ',num2str(sdinc,'%0.4f')]);
disp(['Flatness |  ',num2str(fl,'%0.4f'),' |  ',num2str(flcoh,'%0.4f'),'  |  ',num2str(flinc,'%0.4f')]);
disp(['Skewness |  ',num2str(sk,'%0.4f'),' |  ',num2str(skcoh,'%0.4f'),'  |  ',num2str(skinc,'%0.4f')]);
    
%% Plot the compression curve for the OWT of the signal
% Here we plot the compression curve of the OWT coefficients of the signal.
    swc = sort(abs(wc(wc~=0)),'descend'); % sorted wavelet coefficients

%or we can use
    swc = compressioncurve(sig);
    figure;%set(gcf,'visible','off');
    semilogy(swc);
        [miny maxy] = plotlimits(swc(1:N/2));
        axis([-1 numel(sig)/2 min(swc(1:N/2)) maxy]);
        line([Nc Nc],[min(swc(1:N/2)) maxy]);
    xlabel('Coefficient Number');ylabel('abs(Coefficient)');title('Compression curve');
    
    
%%%%%%%%%%%%%%%%%%%%%%
%% Plot the separation
figure;%set(gcf,'visible','off');
    plot(sig,'g');hold on;
    plot(coh,'r');plot(inc,'--b');
    xlabel('Measurement #');ylabel('Signal value');
        [miny maxy] = plotlimits(sig);
        axis([0 N miny maxy]);
    legend('total','coherent','incoherent');
    
figure;%set(gcf,'visible','off'); % plot zoom
    plot(sig,'-*g');hold on;
    plot(coh,'r');plot(inc,'--b');
    xlabel('Measurement #');ylabel('Signal value');
        [miny maxy] = plotlimits(sig(st:ed));
        axis([st ed miny maxy]);
    legend('total','coherent','incoherent');
%%%%%%%%%%%%%%%%%%%%% 
%% Plot the PDF of the coherent - incoherent split
% Here we plot the PDF of the coherent and incoherent components

    [Pcoh,Xcoh] = nmpdf(coh(coh~=0)); 	% estimate the PDF of the coherent component
    [Pinc,Xinc] = nmpdf(inc(inc~=0)); 	% estimate the PDF of the incoherent component
	figure;%set(gcf,'visible','off');
    semilogy(Xsig,Psig,'g');hold on;semilogy(Xcoh,Pcoh,'r');semilogy(Xinc,Pinc,'--b');
	xlabel('Value');ylabel('Probability');legend('Signal','Coherent','Incoherent'); 
    
%% Plot energy spectrum (periodogram)
 	
    [E,k] = spectrum1D(sig);	% calculate energy spectrum       
    [Ecoh,kcoh] = spectrum1D(coh);	% calculate energy spectrum of the coherent component
    [Einc,kinc] = spectrum1D(inc);	% calculate energy spectrum of the incoherent component

    figure;%set(gcf,'visible','off');
    loglog(k,E,'g');hold on;
    loglog(kcoh,Ecoh,'r');loglog(kinc,Einc,'--b');
%loglog(k,30*k.^-2,'--k','linewidth',2);
    xlabel('k');ylabel('E(k)');title('Energy spectrum of signal');%legend('Signal','Coherent','Incoherent','k^{-2}',3);
    legend('Signal','Coherent','Incoherent',3);
   [miny maxy]=plotlimits(E);A = axis;axis([A(1) A(2) min(E) maxy]);

%% Plot OWT Wavelet Scalogram
[scales,Ewc] = OWTwaveletscalogram1D(sig);
[scales,Ew_coh] = OWTwaveletscalogram1D(coh);
[scales,Ew_inc] = OWTwaveletscalogram1D(inc);

figure;
    semilogy(scales,Ewc,'sg');hold on;
    semilogy(scales,Ew_coh,'*r');
    semilogy(scales,Ew_inc,'*b');
    
    xlabel('scale j');ylabel('E_j, energy in wavelet coefficients at scale j');

% %% Plot energy spectrum with Wavelet scalogram (periodogram)
% % The wavelet scalogram (calculated from the coefficients of the CWT) are
% % plotted as the asterik symbols for the total signal (black), the coherent
% % component (magenta), and the incoherent component (yellow).
%     [kw,Ew] = waveletspectrum1D(sig);
%     [kw_coh,Ew_coh] = waveletspectrum1D(coh);
%     [kw_inc,Ew_inc] = waveletspectrum1D(inc);
%    figure;%set(gcf,'visible','off');
%    loglog(k,E,'g');hold on;
%    loglog(kcoh,Ecoh,'r');loglog(kinc,Einc,'--b');
% %   loglog(k,200*k.^-2,'--k','linewidth',2);
%    loglog(kw,Ew,'*k');hold on;
%    loglog(kw_coh,Ew_coh,'*m');hold on;
%    loglog(kw_inc,Ew_inc,'*y');hold on;
%    xlabel('k');ylabel('E(k)');title('Energy spectrum of signal');%legend('Signal','Coherent','Incoherent','k^{-2}',3);
%    legend('Signal','Coherent','Incoherent',3);
%    [miny maxy]=plotlimits(E);A = axis;axis([A(1) max(k) min(E) maxy]);

%     [kw,Ew] = OWTwaveletspectrum1D(sig);
%     [kw_coh,Ew_coh] = OWTwaveletspectrum1D(coh);
%     [kw_inc,Ew_inc] = OWTwaveletspectrum1D(inc);
% % 
%     loglog(kw,Ew,'sk');hold on;
%     loglog(kw_coh,Ew_coh,'sm');hold on;
%     loglog(kw_inc,Ew_inc,'sy');hold on;

   

% 3/27/2007 Jori
%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
