function [scales,Ewc] = OWTwaveletscalogram1D(sig)
% Calculate the 1D wavelet scalogram of a signal from the OWT coefficients
%
% *** The input signal must be of length 2^n
%
% Usage:
%   [scales,Ewc] = OWTwaveletscalogram1D(sig);
%
% Inputs:
%   sig - signal
%
% Outputs:
%   scales - scale indices (i.e. 0 to n-1, for signals of length 2^n)
%   Ewc - energy caculated in the given wavenumber
%
% See also: WAVELETSPECTRUM1D, WAVELETSPECTRUM2D, SPECTRUM1D, SPECTRUM2D, ENERGYSPECTRUM2D
%
%


% Note: this needs to be adjusted for the wavenumber of particular wavelet
% used.
%


% generate quadrature mirror filter for use with wavelet transform
qmf=makeonfilter('Coiflet',2); % use Coiflet

% take the wavelet transform
wc=fwt_po(sig,0,qmf);

N = length(sig);
n = log2(N);
% wavelet spectrum
scales = [0:(n-1)]; % scale indices 0 = system size

for j=0:n-1; % loop through scales of the DWT transform
    in = 2^(j)+1:2^(j+1); % indices at given scale
    
%    Ewc(j+1) = sum(wc(in).^2); % total energy at scale j
    Ewc(j+1) = mean(wc(in).^2); % total energy at scale j

end %j

Ewc = Ewc/N; % check this normalization

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
