function [kwc,Ewc] = OWTwaveletspectrum2D(sig,x)
% Calculate the 2D wavelet spectrum of a signal from the OWT coefficients
%
% *** The input signal must be of length 2^n
%
% Usage:
%   [kwc,Ewc] = OWTwaveletspectrum2D(sig,x);
%
% Inputs:
%   sig - signal
%   x   - (optional) x positions, sed to calculate proper wavenumbers
%
% Outputs:
%   kwc - wavenumbers
%   Ewc - energy caculated in the given wavenumber
%
% See also: WAVELETSPECTRUM1D, WAVELETSPECTRUM2D, SPECTRUM1D, SPECTRUM2D, ENERGYSPECTRUM2D
%
%
% Note: this needs to be adjusted for the wavenumber of particular wavelet
% used.
%



% generate quadrature mirror filter for use with wavelet transform
qmf=makeonfilter('Coiflet',2); % use Coiflet

% take the wavelet transform
wc=FWT2_PO(sig,0,qmf);
[Scoef,Hcoef,Vcoef,Dcoef] = dwt_levels2D(wc);


N = length(sig);
n = log2(N);
% wavelet spectrum
scales = 2.^-[0:(n-1)]; % scales 1 = system size

nls = length(Hcoef); % number of levels


if nargin<2
    L=1;
else
    %Lx = max(x(:))-min(x(:));Ly = max(y(:))-min(y(:));
    L = max(x(:))-min(x(:));
end %if


kwc = 1./scales/L; % wavenumbers for wavelet scales (?) check this


for i = 1:nls
    %mean energies
    eH(i) = mean(Hcoef{i}(:).^2);
    eV(i) = mean(Vcoef{i}(:).^2);
    eD(i) = mean(Dcoef{i}(:).^2);
    eL(i) = mean(Hcoef{i}(:).^2 + Vcoef{i}(:).^2 + Dcoef{i}(:).^2);
    eL(i) = eL(i)*kwc(i);
end %i


Ewc = eL;

Ewc = Ewc/N/N; % check this normalization

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
