function [I,v_out] = ExtractionCoreMAD(X,c,v)
%EXTRACTIONCOREMAD estimates the variance of a noise with Median absolute deviation (no iteration)
%
% Core function of the extraction procedure.
% This version uses MEDIAN absolute deviation and no iterative algorithm.
% Included mainly for comparison purposes
%	
% Usage :
%	 [I,v] = ExtractionCoreMAD(X , c [, v_0])
%
% Inputs :
%	 X - data, vector of length N
% 	 c - quantile. if a negative value if given, c will be estimated based on the length of X
%	 v_0 - maximum value for the variance (default : no maximum)
%
% Outputs :
% 	 I - indexes of the outliers
%	 v - variance estimate. equals NaN if the estimate falls above v_0
%
% Example
%   X = randn(1,512);
%   var(X) % ~= 1;
%   X(1) = 100; %include an outlier
%   var(X) % ~= 20
%   [I,v] = ExtractionCoreMAD(X,-1) % I = 1, v ~= 1
%
% See also ExtractionCoreL2, ExtractionCoreL1

% Version 0.1 RNVY 19/06/07
% Version 1.0 RNVY 07/08/12

% tuning
sec = 1;

if(c < 0)
    if(isreal(X))
	c = sqrt(2*log(length(X)));
    else
	c = sqrt(log(length(X)));
    end
end

v_out = (myMAD(X(:)))^2;
I = find(abs(X(:)) > sqrt(v_out)*c);

if(nargin > 2)
if(v_out > v*sec)
	v_out = nan;
end
end

end

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
