function handle = ColorbarThreshold(varargin)
%COLORBARTHRESHOLD plots a colorbar for thresholded coefficients
%
% Usage :
%   handle = ColorbarThreshold(palette, min, threshold, max, orientation, ...)
%
% Input :
%   palette - colormap to use
%   min, threshold, max - colorspace boundaries 
%   orientation - h for horizontal, v for vertical
%   
%   ... - all other arguments are passed to colorbar(...)
%
% Outputs :
%   handle - handle to the colorbar

% Create colorbar
C1 = varargin{1};
[minc1, threshold, maxc1] = deal(varargin{2:4});
ratio = (threshold-minc1)/(maxc1-minc1);
orientation = varargin{5};


handle = colorbar(varargin{6:end});
tt = get(handle, 'Children');
N = length(C1);

Nthresh = floor(N*ratio);
cdata = [repmat(C1(1,:),Nthresh,1); C1(2:end,:)];

switch(orientation)
    case 'h'
        sdata = 'XData';
        slim = 'XLim';
        osdata = 'YData';
        oslim = 'YLim';
        cdata = shiftdim(cdata, -1);
        size(cdata)
    case 'v'
        sdata = 'YData';
        slim = 'YLim';
        osdata = 'XData';
        oslim = 'XLim';
        cdata = cdata';
        cdata = shiftdim(cdata, -1);
        cdata = shiftdim(cdata, 2);        

    otherwise
        error('Bad orientation : %s', orientation);
end



set(tt, 'CData', cdata);
set(tt, sdata, [(minc1),(maxc1)]);
set(tt, osdata, [1,1]);
set(handle, oslim, [0.5, 1.5]);
%set(handle, oslim, [-10.5, 10.5]);
set(handle, slim, [(minc1) (maxc1)]);
%set(handle, slim, [-10 10]);

end %function