function DTCWT2D_display(Xl, Xh, mode)
%DTCWT2D_DISPLAY display dtcwt coefficients as an image
%
% Uses N. Kingsbury's method, putting the scaling function coefficients in
% the middle and the subbands around.
% Currently there is a problem when one zooms for example on the wavelet
% coefficients, the scaling function coefs do not follow
%
% Usage :
%   DTCWT2D_display(Xl, Xh)
%
% Inputs :
%   Xl, Xh - DTCWT coefficients as returned by dtwavexfm2
%
% Example
%   X = randn(512);
%   [Xl,Xh] = dtwavexfm2(X, 3, 'near_sym_b', 'qshift_b');
%   DTCWT2D_display(Xl,Xh);
%
% See also : createfigure_subbands, NestedSquaresW

if(nargin < 3)
    mode = 'energy';
end

[N,M,S] = size(Xh{1});
J = log2(N);
if((N ~= M )|| (S ~= 6) || (J ~= floor(J)))
    error('Bad array of coefficients');
end
% original image size
N = 2*N;
J = J+1;
nscales = length(Xh);
L = J-nscales;

% positive angles subbands
wcg = zeros(N, N);
% negative angles subbands
wcd = zeros(N, N);

lx = zeros(2,L-J, 4);
ly = lx;

for j = L:(J-1)
    wcg(dyad(j), dyad(j)) = fliplr(Xh{J-j}(:,:,2));
    wcg(1:2^j, dyad(j)) = fliplr(Xh{J-j}(:,:,1));
    wcg(dyad(j), 1:2^j) = fliplr(Xh{J-j}(:,:,3));
    wcd(dyad(j), dyad(j)) = Xh{J-j}(:,:,5);
    wcd(1:2^j, dyad(j)) = Xh{J-j}(:,:,6);
    wcd(dyad(j), 1:2^j) = Xh{J-j}(:,:,4);

    lx(:,j, 1) = N-2^j + 0.5;
    ly(:,j, 1) = [-0.5, 2*2^j+0.5];
    lx(:,j, 2) = 2*N - lx(:,j,1);
    ly(:,j, 2) = ly(:,j,1);
    lx(:,j, 3) = [N-2^(j+1)+0.5, N+2^(j+1)-0.5];
    ly(:,j, 3) = 2^j+0.5;
    lx(:,j, 4) = N+0.5;
    ly(:,j, 4) = [2^j+0.5, 2^(j+1)+0.5];
end

switch(mode)
    case 'energy'

        rcb = 0.1;
        r = (length(Xl)/2) / (N+length(Xl)/2);
        rx = length(Xl) / (2*N);

        scrsz = get(0,'ScreenSize');
        fig_height =  scrsz(3) * (1-rcb)/(1-r)/2;
        figure('Position', [1,  fig_height, scrsz(3) ,fig_height], ...
            'PaperPositionMode', 'auto');

        h1 = axes('position',[0, 0, 1-rcb, 1-r]);

        h2 = axes('position',[(0.5-rx/2)*(1-rcb), 1-2*r, rx*(1-rcb), 2*r]);

        im = log10(abs([fliplr(wcg), wcd]).^2);
        imagesc(im, 'Parent',h1);

        imagesc(log10(abs(Xl.^2)), 'Parent', h2), colormap('jet');
        axes(h1), axis tight, axis off,caxis([max(im(:)) - 10, max(im(:))]);
        cbar = colorbar('Position', [1-rcb, 0, rcb/2, 1-r]);
        hold all;
        plot(lx(:,:), ly(:,:), 'k-');
        box on;


        axes(h2), axis tight, axis off,caxis([-5, max(im(:))]);

    otherwise
        error('undefined display mode');
end

end


