%PALETTETHRESHOLD generates a colormap for thresholded 2D wc
%
% Suitable for representation of a matrix with two
% families of elements :
%   - "discarded" elements (first elements of the colormap)
%   - positive elements
% 
% Usage :
%   cmap = PaletteThreshold([N])
%
% Input : 
%   N - number of colors (def : 512)
%
% Output : 
%   cmap - colormap to be used eg. with ind2rgb
%
% See also PaletteMarie2, RGBThreshold

function cmap = PaletteThreshold(N)

if(nargin < 1)
    N = 512;
end

% Set colors to use in colormap
zero=[255 255 255]/255;   % for incoherent coefficients
small = [0 0 0]; %for small coefs
large = [0 0.5 0]; % for large coefs
verylarge = [0 1 0]; % for very large coefs

% build colormap !
n1 = floor((N-1)/2);
cmap = [ zero ; linspace(0,1,n1)'*large+linspace(1,0,n1)'*small; linspace(1,0,N-1-n1)'*large+linspace(0, 1, N-1-n1)'*verylarge];

end