%RGBTHRESHOLD converts a matrix of thresholded 2D wc to rgb
%
% All coefficients equal to "nan" are shown using a special color.
% The square modulus of remaining coefficients is shown using a log scale
% 
% Usage :
%   [image_coefs,cmap] = RGBThreshold(coefs [,minc1,maxc1])
% 
% Inputs :
%   coefs - matrix
%   minc1, maxc1 - extrema of the colormap (def: extrema of coefs)
%
% Outputs :
%   image_coefs - image ready to be plotted
%   cmap - colormap that was used
% An image will be generated if no output is requested
%
% See also PaletteInterface, createfigure_subbands


function [coefsRGB,cmap] = RGBThreshold(coefs,minc1,maxc1)

cmap = PaletteThreshold(512);

Icoh = ~isnan(coefs);

if(nargin < 2)
    minc1 = min(coefs(Icoh));
else
    coefs(coefs < minc1) = minc1;
end

if(nargin < 3)
    maxc1 = max(coefs(Icoh));
else    
       coefs(coefs > maxc1) = maxc1;

end

coefs(~Icoh) = 1;
coefs(Icoh) = 2 + floor((coefs(Icoh) - minc1) / (maxc1-minc1) * 511);
coefsRGB = ind2rgb(coefs, cmap);

if(nargout == 0)
    figure;
    image(coefsRGB);
    set(gca,'DataAspectRatio', [1 1 1]);
    axis off;
end

end