function H = h_f(n,type);
%H_F Internal routine for computing quadrature mirror filters for the Shannon and Meyer wavelets.

% Version 1.0 Rodrigo Pereira & RNVY 2010-2012

switch type

    case 'shannon' % Generate Shannon filter 

ks = ifftshift([-n/2:n/2-1])/n;

%Nouvelle definition ondelettes de Shannon
H = (sqrt(2)) * ( ((2*ks)>=-0.5) & ((2*ks)<=0.5)); 
H(2*ks == 0.5) = 1;
H(2*ks == -0.5) = 1;
% correct according to C.Cattani, “Shannon Wavelets Theory”, Mathematical Problems in Engineering, vol. 2008, Article ID 164808, 24 pages, (2008)

    case 'meyer' % Generate Meyer filter

% Ondelette de Meyer (cf. S. Mallat, A wavelet tour of signal processing, p.247-248)
H = zeros(1,n);
H(abs(ks) <= 1/6) = sqrt(2);
u = 6*abs(ks(abs(ks) > 1/6 & abs(ks) < 1/3))-1;
H(abs(ks) > 1/6 & abs(ks) < 1/3) = sqrt(2) * cos(pi/2* u.^4 .* (35-84*u+70*u.^2-20*u.^3));

    otherwise
        disp('Unknown type. Please input either Shannon or Meyer');
        return;
    end

end

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
