function ys = ifwt_shannon(wc,pf)
%IFWT_SHANNON Computes inverse 1D FWT in Fourier space with periodic Shannon Wavelet
%
% Input
%   wc - wavelet coefficients (obtained from fwt_shannon)
%   pf - 'p' or 'f' if output to be in physical or Fourier space (default: p) 
%
% Output
%   ys - signal from inverse transform, defined on the domain [0,1[

% Version 1.0 Rodrigo Pereira & RNVY 2010-2012

if(nargin < 2)
	pf = 'p';
end

wavelet_toolbox_config;
type = shannon_or_meyer;

%% Spatial resolution
N=length(wc);
J = log2(N);

c = [wc(1) wc(1)]/2;
d = [wc(2) wc(2)]/2;

% Applying H and G filters recursively

for j=1:J-1

	n=2^j;

	Fys = (c) .* h_f(n,type) + (d) .* g_f(n,type);

% Upsampling in Fourier space
	c = [Fys Fys]/2;
	d = fft(wc( n+(1:n) ))/(n);
	d = [d d]/2;

end %for j

	Fys = (c) .* h_f(2*n,type) + (d) .* g_f(2*n,type);

    switch pf

        case 'f'
        	ys = Fys*N*sqrt(N);

        case 'p'
		ys = ifft(Fys,'symmetric')*N*sqrt(N);

        otherwise 
            disp(['Invalid option: ',pf]);
            return;

    end % switch

end

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
