function A = RowColRepeat(B,j)
%RowColRepeat repeats rows and columns of a matrix
%
% This allows 'upsampling' by a power of 2
% (used for tree representation of 2D wavelet transform)
%
% Usage :
%    A = RowColRepeat(B,j)
%
% Inputs :
%  B - input matrix of size NxM
%  j - upsampling factor (integer)
%
% Outputs :
%   A - 'upsampled' matrix of size (2^j N)x(2^j M)
%
% Example
%   X = [1 2];
%   Y = RowColRepeat(X,1) % = [1 1 2 2; 1 1 2 2]
%
% See also ConfrontTreeW2D

% Version 0.1 RNVY 20/06/07
%

[N,M] = size(B);
A = B(ceil((1:(2^j*N))/2^j),ceil((1:(2^j*M))/2^j));

end
%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
