function X_t = WavelabWC(Yl, Yh)
%WAVELABWC converts 1D COMPLEX wc from cell ordering to wavelab ordering
%
% Undoes the effect of CellWC, coming back to wavelab ordering.
% This function has to be applied directly to the output of dtwavexfm, in
% which case the vector Y_h will be complex. It is used by
% ExtractionPropCWT.
% 
% Usage :
%   Y_t = WavelabWC(Yl, Yh)
%
% Example
%   [Yl,Yh] = dtwavexfm(randn(2^14,1), 7, 'near_sym_b', 'qshift_b');
%   X_t = WavelabWC(Yl,Yh);
%   size(X_t) % = [1,2^14];
%
% See also CellWC

% Version 0.1 RNVY 20/06/07
%

if(isempty(Yl))
    Yl = zeros(2*length(Yh{end}(:)),1);
end
N_0 = length(Yl);
X_t = [Yl(1:2:(N_0-1)).' + i*Yl(2:2:N_0).', (cat(1,Yh{length(Yh):-1:1}).')];

end

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
