function Y_t = WavelabWC2D(Yl, Yh)
%WAVELABWC2D converts 2D REAL wc from cell ordering to wavelab ordering
%
% Undoes the effect of CellWC2D, coming back to wavelab ordering.
% This function can't be applied to the output of dtwavexfm2, which contain
% 6 subbands.
% 
% Usage :
%   Y_t = WavelabWC2D(Yl, Yh)
%
% Inputs :
%   Yl, Yh - wavelet coefficients. Yh must have only 3 subbands.
%
% See also CellWC2D

% Version 0.1 RNVY 20/06/07
%


% gather and check
[N,L] = quadlength(Yl);
[N,J] = quadlength(Yh{1});
N = 2*N;
J = J+1;

% initialize output
Y_t = zeros(N);

% gather scaling function coefs
Y_t(1:2^L, 1:2^L) = Yl;

% gather wavelet coefs
for j = L:(J-1)
    Y_t(dyad(j), 1:2^j) = Yh{J-j}(:,:,1);
    Y_t(dyad(j),dyad(j)) = Yh{J-j}(:,:,2);
    Y_t(1:2^j,dyad(j))  = Yh{J-j}(:,:,3);
end


end

%  This file is part of the ENS Wavelet Toolbox 
%  Copyright (C) 2006-2012 LMD-ENS-CNRS-Universite Paris 11 - Romain Nguyen van yen, Rodrigo Pereira, Jori Ruppert-Felsot
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
