function [wc,sc] = CWT_test_fun(ys,sc,pf,type);
% [wc,sc] = CWT_test_fun(ys,sc,pf,type);
% Test the CWT starting with the representation of the
% wavelet in physical space or Fourier space
% ** Uses the complex Morlet wavelet or the Mexican hat
%
% Inputs
%   ys - input signal
%   sc - scales at which to perform the transform
%   pf - 'p' or 'f' for physical or Fourier-based Morlet
%   type - 'cmorl' for complex Morlet ; 'mexh' for mexican hat
% Outputs
%   wc - wavelet coefficients
%   xs - positions
%   sc - scales
%
close all;
    
    % check wavelet
    if ~strcmp(type,'cmorl') && ~strcmp(type,'mexh');
        disp(['Unknown wavelet type ',type]);
        return;
    end %if

N = length(ys); % length of signal
nscales = length(sc); % total number of scales in decomposition


Fys = fft(ys); % Fourier transform of the signal


wc = zeros(nscales,N);
% perform complete decomposition
for j=1:nscales; % loop over scales

    % current scale
        L = sc(j);
    
        switch pf
            case 'f'
        %% Fourier space wavelet
        % *** This seems to give result at correct location
        % generate the wavelet at the current scale

        if strcmp(type,'cmorl')   
            Fmo = gen_cmorlet(N,L,'f');
            else
            Fmo = gen_mexh(N,L,'f');            
        end %if
            % multiply the Fourier transforms to take the CWT
        Fwc = Fys.*conj(Fmo);

            case 'p'

        %% Physical space wavelet
        % generate the wavelet at the current scale

        if strcmp(type,'cmorl')
            Fmo = fft(gen_cmorlet(N,L,'p'))/N;
        else
            Fmo = fft(gen_mexh(N,L,'p'))/N;
        end %if

        
        % multiply the Fourier transforms to take the CWT
        Fwc = Fys.*conj(Fmo);
        
            otherwise 
                disp(['Invalid option: ',pf]);
                return;
        end % switch
        
        WC = ifft(Fwc); % Computed wavelet coefficients

        wc(j,:) = WC;

end % loop over scales


% Modified 4/26/2006 Jori
% from CWT_test_P1.m