function PaletteMarie = PaletteMarie2(N, fmin, fmax, fz, weaklimit, zerospread,type)
% Generates a colormap for use with 
%
% Usage:
%   ColorPalette = PaletteMarie2(N, fmin,fmax, fz, weaklimit, zerospread, type)
%
% N = number of elements in the colormap
% fmin = minimum value on the colorscale
% fmax = maximum value on the colorscale
% fz   = location of 'zero' on colorscale (default = 0)
% weaklimit = limit of strong and weak vorticity
% zerospread = zero spreadding; number of elements in colormap corresponding to zero
%
% type (optional) : 
%           'lin' = (default) for a linear variation in colormap intensity
%           'log' = for a logarithmic variation in colormap intensity 
%
% If the field to display is in the 2D matrix, f
% then typically this function can be used as
% ex.
% ColorPalette = PaletteMarie2(256, min(f(:)), max(f(:)), 0, 0.1*(max(f(:))-min(f(:)) ), 2,'lin');
% colormap(ColorPalette);
%
% See also: PALETTEMARIE
%

% Modified/Updated 1/25/2007 Jori

% Set colors to use in colormap
     color1=[0 0 1]; % Blue [0 0 1], for negative values
     color2=[1 1 1]; % Black [1 1 1], for grayscale region around weak values
     color3=[1 0 0]; % Red [1 0 0], for positive values
     zero=[1 1 0];   % Yellow [1 1 0], corresponding to the zero (or center of the colormap)
     
    
     f2 = fmax;% maximum value in colormap
     f1 = fmin; % minimum value in colormap
     %fz = 0; % zero location
     L = weaklimit; % limit of small magnitude values around fz (zero)

     % The following correspond to the number of elements in the colormap
     % that correspond to the different colors ( ranges )
     zero_moins = floor( L/(f2-f1) * N ) - (zerospread/2);
     zero_plus =  floor( L/(f2-f1) * N ) - (zerospread/2);

     
     limite_basse = ceil( (fz-f1)/(f2-f1) * N) - (zerospread/2) - zero_moins;
     limite_haute = floor( (f2- (fz) )/(f2-f1) * N) - (zerospread/2) - zero_plus;
     

     % check for existance of 'type' input
          if ~exist('type','var');
              type = 'lin';
          end %if

          
          switch lower(type)
              case 'lin'
                  disp('Using linear colormap...');
PaletteMarie = [ linspace(0,1,limite_basse)'*color1; linspace(0,0.5,zero_moins)'*color2; ones(zerospread,1)*zero; linspace(0.5,1,zero_plus)'*color2; linspace(0,1,limite_haute)'*color3 ];
              case 'log'
                  disp('Using logarithmic colormap');
                  % note, the arguments in the logspace might need
                  % adjustment to change how fast the intensity of the
                  % colormap varies
PaletteMarie = [ fliplr((1-logspace(-0.8,0,limite_basse)))'*color1; linspace(0,0.5,zero_moins)'*color2; ones(zerospread,1)*zero; linspace(0.5,1,zero_plus)'*color2; fliplr((1-logspace(-2,0,limite_haute)))'*color3 ];
              otherwise
                  disp('Unknown type, please use either "lin" or "log" ');
          end 