function doCWTanalysis(sig)

% Perform a CWT analysis of the input signal
% Note: the length of the signal must be 2^n

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Statistics of the field %
stats=signalstats(sig);
N = stats.N; % length of the signal
mn = stats.mean;
sd = stats.std;
fl = stats.flatness;
sk = stats.skewness;

%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Display the data
%[miny maxy] = plotlimits(sig);
figure;%set(gcf,'visible','off');
plot(sig);%axis([0 numel(sig) miny maxy]);
xlabel('Sample number');ylabel('Signal value');title('Signal');

if N>2000;
% Make a close-up plot of the signal
figure;%set(gcf,'visible','off');
st = N/2-350;ed = N/2+350;
%[miny maxy] = plotlimits(sig(st:ed));
plot(sig);%axis([st ed miny maxy]);
xlabel('Sample number');ylabel('Signal value');title('Close-up of signal');
end %if


%% Scales of the CWT
numoct = floor(log2(N)); % number of octaves in the signal
nvpo = 8; % number of voices per octave
scales = cwscales(numoct,nvpo); % scales to use, system size = 1
scales = 2.^(-[0:(numoct-4)*nvpo]/nvpo);
as = cwscale(scales,'sc2a');

%% Take the CWT of the signal
[sig_wc,as] = cwt1d(sig(:)',as);

%% Display the coefficients of the CWT
% We use our drawCWT1D function to display the modulus and phase of the coefficients
disp(['Signal coefficients: min: ',num2str(min(abs(sig_wc(:)))),' | max: ',num2str(max(abs(sig_wc(:))))]);
H=drawCWT1D(sig_wc,sig,as);
figure(H(1));xlabel('Phase');%set(gcf,'visible','off');
figure(H(2));xlabel('CWT coefficients modulus');%set(gcf,'visible','off');

%% Calculate the local intermittency facor
sc = cwscale(as,'a2sc');
sig_I_lx = intfactor1D(sig_wc,sc);

%% Display the local intermittency factor
disp(['Signal int. factor: min: ',num2str(min(abs(sig_I_lx(:)))),' | max: ',num2str(max(abs(sig_I_lx(:))))]);
drawLIF1D(sig_I_lx,sig,as);xlabel(['Intermittency factor']);


%% Plot energy spectrum with wavelet periodogram
% The wavelet scalogram (calculated from the coefficients of the CWT) are
% plotted as the asterik symbols for the total signal (black), the coherent
% component (magenta), and the incoherent component (yellow).

    [kw,Ew] = waveletspectrum1D(sig);
    [E,k] = spectrum1D(sig);	% calculate Fourier energy spectrum       

    figure;%set(gcf,'visible','off');
    loglog(k,E,'g');hold on;
    xlabel('k');ylabel('E(k)');title('Energy spectrum of signal');
   %[miny maxy]=plotlimits(E);A = axis;axis([A(1) A(2) min(E) maxy]);
    
   loglog(kw,Ew,'*k');hold on;
   legend('Fourier spectrum','Wavelet spectrum',3);
   %[miny maxy]=plotlimits(E);A = axis;axis([A(1) max(k) min(E) maxy]);

end

% 3/27/2007 Jori
% 8/6/2012 Romain
