function [wp,x] = make_physical_morlet(N,L,k_0,x_0);
% [wp,x] = make_physical_morlet(N,L,k_0,x_0);
% Generation of a Complex Morlet wavelet in physical space
% calculated on the domain [0,1)
% Use the proper plane-wave modulated by a Gaussian form
%
% Returns either the wavelet in physical space or in
% Fourier space, depending upon the input 'type'
%
% Input:
%   N   - number of points
%   L   - scale, 1 = no scaling
%   k_0 - wavenumber of Morlet
%   x_0 - center of the wavelet in physical space (default should be 0.5, in the center of the domain)
%
% Output:
%   wp - Complex Morlet wavelet in physical space
%   x  - positions where wavelet is calculated


%    x = [-N/2:N/2 - 1]*(1/N); % periodic domain size = 1 from -1/2 -> 1/2
    x = [0:N - 1]*(1/N); % periodic domain size = 1 from [0,1)
   
    xs = (x-x_0)/L;
    
    mo = ( exp(i*k_0*xs) - exp(-k_0^2/2) ) .* exp(-xs.^2/2);
    mo = (1/sqrt(L))*mo; % renormalize due to scale change
    
    wp = mo; % assign output
    % **note that this physical space representation is not periodized

% Created 4/26/2006 Jori