% Plot a cut of the 2D complex Morlet wavelet
% and compare it with the 1D complex Morlet wavelet
% to make sure that there is agreement between the two
close all;clear all;

N = 1024; % linear dimension of the wavelet domain
theta = 0; % rotation of the 2D wavelet
a = 0.01; % dilation parameter

% compare the physical space wavelets
[w1D,x] = gen_cmorlet(N,a,'p');
[w2D,x] = gen_cmorlet2D(N,a,theta,'p');
[fw2D,k] = gen_cmorlet2D(N,a,theta,'f');

    [x2D,y2D] = meshgrid(x);
    [kx2D,ky2D] = meshgrid(k);



    % Physical space
figure;
    imagesc(abs(w2D));axis image;
figure;
    imagesc(abs(fft2(w2D)/N/N));axis image;
    
    
figure;
    plot(x,abs(w1D));hold on;
    plot(x,abs(fftshift(w2D(N/2+1,:)*sqrt(a))),'--r');
    title('1D cut through middle of wavelet');
    % note that the w2D(:,N/2+1) column is not equal to the 1D cut
    % since this is the 'y' axis
legend('1D','cut of 2D');

figure;
    plot(x,real(w1D)-real(fftshift(w2D(N/2+1,:)*sqrt(a))),'-k');hold on;
    plot(x,imag(w1D)-imag(fftshift(w2D(N/2+1,:)*sqrt(a))),'--r');
    title('difference between 1D and 1D cut of 2D wavelet');
    % note that the w2D(:,N/2+1) column is not equal to the 1D cut
    % since this is the 'y' axis
legend('real','imag');

figure;
    plot(x,abs(w1D)-abs(fftshift(w2D(N/2+1,:)*sqrt(a))),'--r');
    title('difference of abs of 1D and 1D cut of 2D wavelet');

    
figure;
    imagesc(abs( fftshift(ifft2(fw2D))*N*N-w2D ));
    colorbar;

figure;
    t = ifft2(fw2D)*N*N;
    plot(k,abs(t(N/2+1,:)) );


    % Fourier space
%figure;
   

figure;
    imagesc(abs(fw2D)-abs(fft2(w2D)/N/N));
    colorbar;

figure; % plot a cut
    t = abs(fft2(w2D)/N/N);
    plot(k,abs(fw2D(:,4)),'k' );hold on;
    plot(k,t(:,4),'--r' );
figure; % plot another cut
    t = abs(fft2(w2D)/N/N);
    plot(k,abs(fw2D(2,:)),'k' );hold on;
    plot(k,t(2,:),'--r' );
figure; % difference
    plot(k,abs(fw2D(2,:) )-t(2,:) );

    
    
    
% Created 5/4/2006 Jori