%CONFIG_EXTRACTION Global wavelet toolbox configuration file 
%
% This script is called from within all the toolbox functions
% so that some parameters can be adjusted globally instead of passing them as
% arguments all the time.
%
% List of parameters :
% * FOR DENOISING IN WAVELET BASES
%  - DTCWT filters (see dtwavexfm)
%  - OWT filters (see MakeONFilter)
%  - coarsest scales of wavelet decomposition, in 1D, and 2D.
%  - coarsest scales of variance estimation, in 1D and 2D
%  - quantile parameters
%  - core function to estimate the variance
%  - thresholding method for coarse scales in ExtractionProp*
%  - whether or not to display a graphical summary for ExtractionProp2D*
%
% * FOR THE SHANNON/MEYER WAVELET TRANSFORM
%  - shannon_or_meyer
%
% * FOR THE CONTINUOUS WAVELET TRANSFORM
%
%
%

%
% * FOR DENOISING IN WAVELET BASES
%  - DTCWT filters (see dtwavexfm)
biort = 'near_sym_b';
qshift = 'qshift_b';

%  - OWT filters (see MakeONFilter)
%qmf = MakeONFilter('Symmlet', 8);
qmf = MakeONFilter('Coiflet', 2);
%qmf = MakeONFilter('Haar');

%  - coarsest scales of wavelet decomposition, in 1D, and 2D.
L_1D = 1;
L_2D = 1;

%  - coarsest scales of variance estimation, in 1D and 2D
L_0_1D = 7;
L_0_2D = 5;

%  - quantile parameters
% All the quantile parameters set to -1 --> will be determined internally
%c_1dcomplex = -1;
c_1dcomplex = -1;
%c_2dcomplex = 3.5/sqrt(2);
c_2dcomplex = -1;
c_1dreal = -1;
%c_2dreal = -1;
c_2dreal = -1;

% Choose core variance estimation function
% By default, we use the standard iterative algorithm
% described in Azzalini et al. , ACHA vol 18 (2004)
ExtractionCore = @ExtractionCoreL2;
% This one is a slight variation on the iterative algorithm
%ExtractionCore = @ExtractionCoreL1;
% We can also use median absolute deviation
%ExtractionCore = @ExtractionCoreMAD;

%  - thresholding method for coarse scales in ExtractionProp*
thresh_coarse_scales = 'fixed';

% configuration for oracle thresholding (ExtractionOpti,
% ExtractionOptiDTCWT)
oracle_mode = 'global'; % global oracle threshold (slow)
%oracle_mode = 'sbs'; % scale by scale oracle threshold (slow)
%oracle_mode = 'cbc'; % coefficients by coefficients oracle threshold (much faster than the 2 others)
oracle_L0_penalization = 0.00;
%  - whether or not to display a graphical summary for ExtractionProp2D*
show_figure = 0;

% number of fine scales left out by Extraction, ExtractionCWT, Extraction2D, Extraction2DCWT
% (undocumented)
scales_out = 0;
proba_max = 0.001;
max_iter = 100;
error_if_not_converged = 0;
output_luminy = 0;

% * FOR THE SHANNON/MEYER WAVELET TRANSFORM
% Choose between shannon and meyer wavelets
shannon_or_meyer = 'shannon';

% * FOR THE CONTINUOUS WAVELET TRANSFORM
%
% Type of wavelet to use (do not change this - only complex Morlet wavelet is supported)
wtype = 'cmorl'; % Complex morlet wavelet

% k_psi parameter for the complex morlet wavelet
kpsi = 6;
% dilation parameter at scale = 1. !! This must be adjusted depending on the value of kpsi
a_sc1 = 0.1329;
 % normalization constant for the inverse wavelet transform. !! This must be adjusted depending on the value of kpsi 
C = 2.2749; 



